Method: Auth0::Api::V2::Emails#get_provider

Defined in:
lib/auth0/api/v2/emails.rb

#get_provider(fields: nil, include_fields: nil) ⇒ json

Get all the email providers.

Parameters:

  • fields (string) (defaults to: nil)

    A comma separated list of fields to include or exclude from the result.

  • include_fields (boolean) (defaults to: nil)

    True if the fields specified are to be included in the result, false otherwise.

Returns:

  • (json)

    Returns the existing email providers.

See Also:



14
15
16
17
18
19
20
# File 'lib/auth0/api/v2/emails.rb', line 14

def get_provider(fields: nil, include_fields: nil)
  request_params = {
    fields:           fields,
    include_fields:   include_fields
  }
  get(email_path, request_params)
end