Method: Auth0::Api::V2::Emails#update_provider

Defined in:
lib/auth0/api/v2/emails.rb

#update_provider(body) ⇒ json

Updates the configured email provider.

Parameters:

  • body (hash)

    The Hash options used to specify the email provider’s properties.

Returns:

  • (json)

    Returns the updated email provider.

Raises:

See Also:



43
44
45
46
# File 'lib/auth0/api/v2/emails.rb', line 43

def update_provider(body)
  raise Auth0::InvalidParameter, 'Must supply a valid body to update an email provider' if body.to_s.empty?
  patch(email_path, body)
end