Method: Auth0::Api::V2::Logs#log

Defined in:
lib/auth0/api/v2/logs.rb

#log(log_id) ⇒ json Also known as: get_logs_by_id

Retrieves log entries that match the specified search criteria.

Parameters:

  • log_id (string)

    The log_id of the log to retrieve.

Returns:

  • (json)

    Returns the log with the given id if exists.

Raises:

See Also:



51
52
53
54
55
# File 'lib/auth0/api/v2/logs.rb', line 51

def log(log_id)
  raise Auth0::MissingParameter, 'Must supply a valid log_id' if log_id.to_s.empty?
  path = "#{logs_path}/#{log_id}"
  get(path)
end