Class: Auth0::Actions::Client
- Inherits:
-
Object
- Object
- Auth0::Actions::Client
- Defined in:
- lib/auth0/actions/client.rb
Instance Method Summary collapse
-
#create(request_options: {}, **params) ⇒ Auth0::Types::CreateActionResponseContent
Create an action.
-
#delete(request_options: {}, **params) ⇒ untyped
Deletes an action and all of its associated versions.
-
#deploy(request_options: {}, **params) ⇒ Auth0::Types::DeployActionResponseContent
Deploy an action.
- #executions ⇒ Auth0::Executions::Client
-
#get(request_options: {}, **params) ⇒ Auth0::Types::GetActionResponseContent
Retrieve an action by its ID.
- #initialize(client:) ⇒ void constructor
-
#list(request_options: {}, **params) ⇒ Auth0::Types::ListActionsPaginatedResponseContent
Retrieve all actions.
- #modules ⇒ Auth0::Modules::Client
-
#test(request_options: {}, **params) ⇒ Auth0::Types::TestActionResponseContent
Test an action.
- #triggers ⇒ Auth0::Triggers::Client
-
#update(request_options: {}, **params) ⇒ Auth0::Types::UpdateActionResponseContent
Update an existing action.
- #versions ⇒ Auth0::Versions::Client
Constructor Details
#initialize(client:) ⇒ void
9 10 11 |
# File 'lib/auth0/actions/client.rb', line 9 def initialize(client:) @client = client end |
Instance Method Details
#create(request_options: {}, **params) ⇒ Auth0::Types::CreateActionResponseContent
Create an action. Once an action is created, it must be deployed, and then bound to a trigger before it will be executed as part of a flow.
100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 |
# File 'lib/auth0/actions/client.rb', line 100 def create(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "POST", path: "actions/actions", body: Auth0::Actions::Types::CreateActionRequestContent.new(params).to_h, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) (response.body.to_s.empty? ? nil : Auth0::Types::CreateActionResponseContent.load(response.body)) else error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#delete(request_options: {}, **params) ⇒ untyped
Deletes an action and all of its associated versions. An action must be unbound from all triggers before it can be deleted.
180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 |
# File 'lib/auth0/actions/client.rb', line 180 def delete(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) query_params = {} query_params["force"] = params[:force] if params.key?(:force) request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "DELETE", path: "actions/actions/#{URI.encode_uri_component(params[:id].to_s)}", query: query_params, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i return if code.between?(200, 299) error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end |
#deploy(request_options: {}, **params) ⇒ Auth0::Types::DeployActionResponseContent
Deploy an action. Deploying an action will create a new immutable version of the action. If the action is currently bound to a trigger, then the system will begin executing the newly deployed version of the action immediately. Otherwise, the action will only be executed as a part of a flow once it is bound to that flow.
264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 |
# File 'lib/auth0/actions/client.rb', line 264 def deploy(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "POST", path: "actions/actions/#{URI.encode_uri_component(params[:id].to_s)}/deploy", request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) (response.body.to_s.empty? ? nil : Auth0::Types::DeployActionResponseContent.load(response.body)) else error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#executions ⇒ Auth0::Executions::Client
340 341 342 |
# File 'lib/auth0/actions/client.rb', line 340 def executions @executions ||= Auth0::Actions::Executions::Client.new(client: @client) end |
#get(request_options: {}, **params) ⇒ Auth0::Types::GetActionResponseContent
Retrieve an action by its ID.
138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 |
# File 'lib/auth0/actions/client.rb', line 138 def get(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "GET", path: "actions/actions/#{URI.encode_uri_component(params[:id].to_s)}", request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) (response.body.to_s.empty? ? nil : Auth0::Types::GetActionResponseContent.load(response.body)) else error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#list(request_options: {}, **params) ⇒ Auth0::Types::ListActionsPaginatedResponseContent
Retrieve all actions.
40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/auth0/actions/client.rb', line 40 def list(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) query_params = {} query_params["triggerId"] = params[:trigger_id] if params.key?(:trigger_id) query_params["actionName"] = params[:action_name] if params.key?(:action_name) query_params["deployed"] = params[:deployed] if params.key?(:deployed) query_params["page"] = params.fetch(:page, 0) query_params["per_page"] = params.fetch(:per_page, 50) query_params["installed"] = params[:installed] if params.key?(:installed) Auth0::Internal::OffsetItemIterator.new( initial_page: query_params["page"], item_field: :actions, has_next_field: nil, step: false ) do |next_page| query_params["page"] = next_page request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "GET", path: "actions/actions", query: query_params, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) parsed_response = (response.body.to_s.empty? ? nil : Auth0::Types::ListActionsPaginatedResponseContent.load(response.body)) [parsed_response, response] else error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end end |
#modules ⇒ Auth0::Modules::Client
345 346 347 |
# File 'lib/auth0/actions/client.rb', line 345 def modules @modules ||= Auth0::Actions::Modules::Client.new(client: @client) end |
#test(request_options: {}, **params) ⇒ Auth0::Types::TestActionResponseContent
Test an action. After updating an action, it can be tested prior to being deployed to ensure it behaves as expected.
307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 |
# File 'lib/auth0/actions/client.rb', line 307 def test(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) request_data = Auth0::Actions::Types::TestActionRequestContent.new(params).to_h non_body_param_names = %w[id] body = request_data.except(*non_body_param_names) request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "POST", path: "actions/actions/#{URI.encode_uri_component(params[:id].to_s)}/test", body: body, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) (response.body.to_s.empty? ? nil : Auth0::Types::TestActionResponseContent.load(response.body)) else error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#triggers ⇒ Auth0::Triggers::Client
350 351 352 |
# File 'lib/auth0/actions/client.rb', line 350 def triggers @triggers ||= Auth0::Actions::Triggers::Client.new(client: @client) end |
#update(request_options: {}, **params) ⇒ Auth0::Types::UpdateActionResponseContent
Update an existing action. If this action is currently bound to a trigger, updating it will not affect any user flows until the action is deployed.
220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 |
# File 'lib/auth0/actions/client.rb', line 220 def update(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) request_data = Auth0::Actions::Types::UpdateActionRequestContent.new(params).to_h non_body_param_names = %w[id] body = request_data.except(*non_body_param_names) request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "PATCH", path: "actions/actions/#{URI.encode_uri_component(params[:id].to_s)}", body: body, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) (response.body.to_s.empty? ? nil : Auth0::Types::UpdateActionResponseContent.load(response.body)) else error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |