Class: Auth0::Actions::Modules::Versions::Client
- Inherits:
-
Object
- Object
- Auth0::Actions::Modules::Versions::Client
- Defined in:
- lib/auth0/actions/modules/versions/client.rb
Instance Method Summary collapse
-
#create(request_options: {}, **params) ⇒ Auth0::Types::CreateActionModuleVersionResponseContent
Creates a new immutable version of an Actions Module from the current draft version.
-
#get(request_options: {}, **params) ⇒ Auth0::Types::GetActionModuleVersionResponseContent
Retrieve the details of a specific, immutable version of an Actions Module.
- #initialize(client:) ⇒ void constructor
-
#list(request_options: {}, **params) ⇒ Auth0::Types::GetActionModuleVersionsResponseContent
List all published versions of a specific Actions Module.
Constructor Details
#initialize(client:) ⇒ void
11 12 13 |
# File 'lib/auth0/actions/modules/versions/client.rb', line 11 def initialize(client:) @client = client end |
Instance Method Details
#create(request_options: {}, **params) ⇒ Auth0::Types::CreateActionModuleVersionResponseContent
Creates a new immutable version of an Actions Module from the current draft version. This publishes the draft as a new version that can be referenced by actions, while maintaining the existing draft for continued development.
80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 |
# File 'lib/auth0/actions/modules/versions/client.rb', line 80 def create(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "POST", path: "actions/modules/#{URI.encode_uri_component(params[:id].to_s)}/versions", request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Auth0::Types::CreateActionModuleVersionResponseContent.load(response.body) else error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#get(request_options: {}, **params) ⇒ Auth0::Types::GetActionModuleVersionResponseContent
Retrieve the details of a specific, immutable version of an Actions Module.
115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 |
# File 'lib/auth0/actions/modules/versions/client.rb', line 115 def get(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "GET", path: "actions/modules/#{URI.encode_uri_component(params[:id].to_s)}/versions/#{URI.encode_uri_component(params[:version_id].to_s)}", request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Auth0::Types::GetActionModuleVersionResponseContent.load(response.body) else error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#list(request_options: {}, **params) ⇒ Auth0::Types::GetActionModuleVersionsResponseContent
List all published versions of a specific Actions Module.
29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 |
# File 'lib/auth0/actions/modules/versions/client.rb', line 29 def list(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) query_param_names = %i[page per_page] query_params = {} query_params["page"] = params.fetch(:page, 0) query_params["per_page"] = params.fetch(:per_page, 50) params = params.except(*query_param_names) Auth0::Internal::OffsetItemIterator.new( initial_page: query_params["page"], item_field: :versions, has_next_field: nil, step: true ) do |next_page| query_params["page"] = next_page request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "GET", path: "actions/modules/#{URI.encode_uri_component(params[:id].to_s)}/versions", query: query_params, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Auth0::Types::GetActionModuleVersionsResponseContent.load(response.body) else error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end end |