Class: Auth0::Actions::Triggers::Client

Inherits:
Object
  • Object
show all
Defined in:
lib/auth0/actions/triggers/client.rb

Instance Method Summary collapse

Constructor Details

#initialize(client:) ⇒ void

Parameters:



10
11
12
# File 'lib/auth0/actions/triggers/client.rb', line 10

def initialize(client:)
  @client = client
end

Instance Method Details

#bindingsAuth0::Bindings::Client

Returns:

  • (Auth0::Bindings::Client)


49
50
51
# File 'lib/auth0/actions/triggers/client.rb', line 49

def bindings
  @bindings ||= Auth0::Actions::Triggers::Bindings::Client.new(client: @client)
end

#list(request_options: {}, **params) ⇒ Auth0::Types::ListActionTriggersResponseContent

Retrieve the set of triggers currently available within actions. A trigger is an extensibility point to which actions can be bound.

Parameters:

  • request_options (Hash) (defaults to: {})
  • params (Hash)

Options Hash (request_options:):

  • :base_url (String)
  • :additional_headers (Hash{String => Object})
  • :additional_query_parameters (Hash{String => Object})
  • :additional_body_parameters (Hash{String => Object})
  • :timeout_in_seconds (Integer)

Returns:



26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
# File 'lib/auth0/actions/triggers/client.rb', line 26

def list(request_options: {}, **params)
  Auth0::Internal::Types::Utils.normalize_keys(params)
  request = Auth0::Internal::JSON::Request.new(
    base_url: request_options[:base_url],
    method: "GET",
    path: "actions/triggers",
    request_options: request_options
  )
  begin
    response = @client.send(request)
  rescue Net::HTTPRequestTimeout
    raise Auth0::Errors::TimeoutError
  end
  code = response.code.to_i
  if code.between?(200, 299)
    Auth0::Types::ListActionTriggersResponseContent.load(response.body)
  else
    error_class = Auth0::Errors::ResponseError.subclass_for_code(code)
    raise error_class.new(response.body, code: code)
  end
end