Class: Auth0::AttackProtection::BreachedPasswordDetection::Client
- Inherits:
-
Object
- Object
- Auth0::AttackProtection::BreachedPasswordDetection::Client
- Defined in:
- lib/auth0/attack_protection/breached_password_detection/client.rb
Instance Method Summary collapse
-
#get(request_options: {}, **params) ⇒ Auth0::Types::GetBreachedPasswordDetectionSettingsResponseContent
Retrieve details of the Breached Password Detection configuration of your tenant.
- #initialize(client:) ⇒ void constructor
-
#update(request_options: {}, **params) ⇒ Auth0::Types::UpdateBreachedPasswordDetectionSettingsResponseContent
Update details of the Breached Password Detection configuration of your tenant.
Constructor Details
#initialize(client:) ⇒ void
10 11 12 |
# File 'lib/auth0/attack_protection/breached_password_detection/client.rb', line 10 def initialize(client:) @client = client end |
Instance Method Details
#get(request_options: {}, **params) ⇒ Auth0::Types::GetBreachedPasswordDetectionSettingsResponseContent
Retrieve details of the Breached Password Detection configuration of your tenant.
25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 |
# File 'lib/auth0/attack_protection/breached_password_detection/client.rb', line 25 def get(request_options: {}, **params) Auth0::Internal::Types::Utils.normalize_keys(params) request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "GET", path: "attack-protection/breached-password-detection", request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Auth0::Types::GetBreachedPasswordDetectionSettingsResponseContent.load(response.body) else error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#update(request_options: {}, **params) ⇒ Auth0::Types::UpdateBreachedPasswordDetectionSettingsResponseContent
Update details of the Breached Password Detection configuration of your tenant.
58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/auth0/attack_protection/breached_password_detection/client.rb', line 58 def update(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "PATCH", path: "attack-protection/breached-password-detection", body: Auth0::AttackProtection::BreachedPasswordDetection::Types::UpdateBreachedPasswordDetectionSettingsRequestContent.new(params).to_h, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Auth0::Types::UpdateBreachedPasswordDetectionSettingsResponseContent.load(response.body) else error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |