Class: Auth0::ClientGrants::Client
- Inherits:
-
Object
- Object
- Auth0::ClientGrants::Client
- Defined in:
- lib/auth0/client_grants/client.rb
Instance Method Summary collapse
-
#create(request_options: {}, **params) ⇒ Auth0::Types::CreateClientGrantResponseContent
Create a client grant for a machine-to-machine login flow.
-
#delete(request_options: {}, **params) ⇒ untyped
Delete the Client Credential Flow from your machine-to-machine application.
-
#get(request_options: {}, **params) ⇒ Auth0::Types::GetClientGrantResponseContent
Retrieve a single client grant, including the scopes associated with the application/API pair.
- #initialize(client:) ⇒ void constructor
-
#list(request_options: {}, **params) ⇒ Auth0::Types::ListClientGrantPaginatedResponseContent
Retrieve a list of client grants, including the scopes associated with the application/API pair.
- #organizations ⇒ Auth0::Organizations::Client
-
#update(request_options: {}, **params) ⇒ Auth0::Types::UpdateClientGrantResponseContent
Update a client grant.
Constructor Details
#initialize(client:) ⇒ void
9 10 11 |
# File 'lib/auth0/client_grants/client.rb', line 9 def initialize(client:) @client = client end |
Instance Method Details
#create(request_options: {}, **params) ⇒ Auth0::Types::CreateClientGrantResponseContent
Create a client grant for a machine-to-machine login flow. To learn more, read Client Credential Flow.
102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 |
# File 'lib/auth0/client_grants/client.rb', line 102 def create(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "POST", path: "client-grants", body: Auth0::ClientGrants::Types::CreateClientGrantRequestContent.new(params).to_h, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) (response.body.to_s.empty? ? nil : Auth0::Types::CreateClientGrantResponseContent.load(response.body)) else error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#delete(request_options: {}, **params) ⇒ untyped
Delete the Client Credential Flow from your machine-to-machine application.
181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 |
# File 'lib/auth0/client_grants/client.rb', line 181 def delete(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "DELETE", path: "client-grants/#{URI.encode_uri_component(params[:id].to_s)}", request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i return if code.between?(200, 299) error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end |
#get(request_options: {}, **params) ⇒ Auth0::Types::GetClientGrantResponseContent
Retrieve a single client grant, including the scopes associated with the application/API pair.
142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 |
# File 'lib/auth0/client_grants/client.rb', line 142 def get(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "GET", path: "client-grants/#{URI.encode_uri_component(params[:id].to_s)}", request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) (response.body.to_s.empty? ? nil : Auth0::Types::GetClientGrantResponseContent.load(response.body)) else error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#list(request_options: {}, **params) ⇒ Auth0::Types::ListClientGrantPaginatedResponseContent
Retrieve a list of client grants, including the scopes associated with the application/API pair.
46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 |
# File 'lib/auth0/client_grants/client.rb', line 46 def list(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) query_params = {} query_params["include_totals"] = params.fetch(:include_totals, true) query_params["from"] = params[:from] if params.key?(:from) query_params["take"] = params.fetch(:take, 50) query_params["audience"] = params[:audience] if params.key?(:audience) query_params["client_id"] = params[:client_id] if params.key?(:client_id) query_params["allow_any_organization"] = params[:allow_any_organization] if params.key?(:allow_any_organization) query_params["subject_type"] = params[:subject_type] if params.key?(:subject_type) query_params["default_for"] = params[:default_for] if params.key?(:default_for) Auth0::Internal::CursorItemIterator.new( cursor_field: :next_, item_field: :client_grants, initial_cursor: query_params["from"] ) do |next_cursor| query_params["from"] = next_cursor request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "GET", path: "client-grants", query: query_params, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) parsed_response = (response.body.to_s.empty? ? nil : Auth0::Types::ListClientGrantPaginatedResponseContent.load(response.body)) [parsed_response, response] else error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end end |
#organizations ⇒ Auth0::Organizations::Client
244 245 246 |
# File 'lib/auth0/client_grants/client.rb', line 244 def organizations @organizations ||= Auth0::ClientGrants::Organizations::Client.new(client: @client) end |
#update(request_options: {}, **params) ⇒ Auth0::Types::UpdateClientGrantResponseContent
Update a client grant.
216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 |
# File 'lib/auth0/client_grants/client.rb', line 216 def update(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) request_data = Auth0::ClientGrants::Types::UpdateClientGrantRequestContent.new(params).to_h non_body_param_names = %w[id] body = request_data.except(*non_body_param_names) request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "PATCH", path: "client-grants/#{URI.encode_uri_component(params[:id].to_s)}", body: body, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) (response.body.to_s.empty? ? nil : Auth0::Types::UpdateClientGrantResponseContent.load(response.body)) else error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |