Class: Auth0::Connections::Users::Client
- Inherits:
-
Object
- Object
- Auth0::Connections::Users::Client
- Defined in:
- lib/auth0/connections/users/client.rb
Instance Method Summary collapse
-
#delete_by_email(request_options: {}, **params) ⇒ untyped
Deletes a specified connection user by its email (you cannot delete all users from specific connection).
- #initialize(client:) ⇒ void constructor
Constructor Details
#initialize(client:) ⇒ void
10 11 12 |
# File 'lib/auth0/connections/users/client.rb', line 10 def initialize(client:) @client = client end |
Instance Method Details
#delete_by_email(request_options: {}, **params) ⇒ untyped
Deletes a specified connection user by its email (you cannot delete all users from specific connection). Currently, only Database Connections are supported.
28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 |
# File 'lib/auth0/connections/users/client.rb', line 28 def delete_by_email(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) query_param_names = %i[email] query_params = {} query_params["email"] = params[:email] if params.key?(:email) params = params.except(*query_param_names) request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "DELETE", path: "connections/#{URI.encode_uri_component(params[:id].to_s)}/users", query: query_params, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i return if code.between?(200, 299) error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end |