Class: Auth0::Guardian::Enrollments::Client
- Inherits:
-
Object
- Object
- Auth0::Guardian::Enrollments::Client
- Defined in:
- lib/auth0/guardian/enrollments/client.rb
Instance Method Summary collapse
-
#create_ticket(request_options: {}, **params) ⇒ Auth0::Types::CreateGuardianEnrollmentTicketResponseContent
Create a [multi-factor authentication (MFA) enrollment ticket](auth0.com/docs/secure/multi-factor-authentication/auth0-guardian/create-custom-enrollment-tickets), and optionally send an email with the created ticket to a given user.
-
#delete(request_options: {}, **params) ⇒ untyped
Remove a specific multi-factor authentication (MFA) enrollment from a user’s account.
-
#get(request_options: {}, **params) ⇒ Auth0::Types::GetGuardianEnrollmentResponseContent
Retrieve details, such as status and type, for a specific multi-factor authentication enrollment registered to a user account.
- #initialize(client:) ⇒ void constructor
Constructor Details
#initialize(client:) ⇒ void
10 11 12 |
# File 'lib/auth0/guardian/enrollments/client.rb', line 10 def initialize(client:) @client = client end |
Instance Method Details
#create_ticket(request_options: {}, **params) ⇒ Auth0::Types::CreateGuardianEnrollmentTicketResponseContent
Create a [multi-factor authentication (MFA) enrollment ticket](auth0.com/docs/secure/multi-factor-authentication/auth0-guardian/create-custom-enrollment-tickets), and optionally send an email with the created ticket to a given user. Enrollment tickets can specify which factor users must enroll with or allow existing MFA users to enroll in additional factors.
28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 |
# File 'lib/auth0/guardian/enrollments/client.rb', line 28 def create_ticket(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "POST", path: "guardian/enrollments/ticket", body: Auth0::Guardian::Enrollments::Types::CreateGuardianEnrollmentTicketRequestContent.new(params).to_h, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Auth0::Types::CreateGuardianEnrollmentTicketResponseContent.load(response.body) else error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#delete(request_options: {}, **params) ⇒ untyped
Remove a specific multi-factor authentication (MFA) enrollment from a user’s account. This allows the user to re-enroll with MFA. For more information, review [Reset User Multi-Factor Authentication and Recovery Codes](auth0.com/docs/secure/multi-factor-authentication/reset-user-mfa).
100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 |
# File 'lib/auth0/guardian/enrollments/client.rb', line 100 def delete(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "DELETE", path: "guardian/enrollments/#{URI.encode_uri_component(params[:id].to_s)}", request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i return if code.between?(200, 299) error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end |
#get(request_options: {}, **params) ⇒ Auth0::Types::GetGuardianEnrollmentResponseContent
Retrieve details, such as status and type, for a specific multi-factor authentication enrollment registered to a user account.
64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 |
# File 'lib/auth0/guardian/enrollments/client.rb', line 64 def get(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "GET", path: "guardian/enrollments/#{URI.encode_uri_component(params[:id].to_s)}", request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Auth0::Types::GetGuardianEnrollmentResponseContent.load(response.body) else error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |