Class: Auth0::Hooks::Secrets::Client
- Inherits:
-
Object
- Object
- Auth0::Hooks::Secrets::Client
- Defined in:
- lib/auth0/hooks/secrets/client.rb
Instance Method Summary collapse
-
#create(request_options: {}, **params) ⇒ untyped
Add one or more secrets to an existing hook.
-
#delete(request_options: {}, **params) ⇒ untyped
Delete one or more existing secrets for a given hook.
-
#get(request_options: {}, **params) ⇒ Hash[String, String]
Retrieve a hook's secrets by the ID of the hook.
- #initialize(client:) ⇒ void constructor
-
#update(request_options: {}, **params) ⇒ untyped
Update one or more existing secrets for an existing hook.
Constructor Details
#initialize(client:) ⇒ void
10 11 12 |
# File 'lib/auth0/hooks/secrets/client.rb', line 10 def initialize(client:) @client = client end |
Instance Method Details
#create(request_options: {}, **params) ⇒ untyped
Add one or more secrets to an existing hook. Accepts an object of key-value pairs, where the key is the name of the secret. A hook can have a maximum of 20 secrets.
72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 |
# File 'lib/auth0/hooks/secrets/client.rb', line 72 def create(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) path_param_names = i[id] body_params = params.except(*path_param_names) request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "POST", path: "hooks/#{URI.encode_uri_component(params[:id].to_s)}/secrets", body: body_params, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i return if code.between?(200, 299) error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end |
#delete(request_options: {}, **params) ⇒ untyped
Delete one or more existing secrets for a given hook. Accepts an array of secret names to delete.
114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 |
# File 'lib/auth0/hooks/secrets/client.rb', line 114 def delete(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) path_param_names = i[id] body_params = params.except(*path_param_names) request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "DELETE", path: "hooks/#{URI.encode_uri_component(params[:id].to_s)}/secrets", body: body_params, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i return if code.between?(200, 299) error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end |
#get(request_options: {}, **params) ⇒ Hash[String, String]
Retrieve a hook's secrets by the ID of the hook.
29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 |
# File 'lib/auth0/hooks/secrets/client.rb', line 29 def get(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "GET", path: "hooks/#{URI.encode_uri_component(params[:id].to_s)}/secrets", request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) (response.body.to_s.empty? ? nil : Auth0::Types::GetHookSecretResponseContent.load(response.body)) else error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#update(request_options: {}, **params) ⇒ untyped
Update one or more existing secrets for an existing hook. Accepts an object of key-value pairs, where the key is the name of the existing secret.
159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 |
# File 'lib/auth0/hooks/secrets/client.rb', line 159 def update(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) path_param_names = i[id] body_params = params.except(*path_param_names) request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "PATCH", path: "hooks/#{URI.encode_uri_component(params[:id].to_s)}/secrets", body: body_params, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i return if code.between?(200, 299) error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end |