Class: Auth0::Keys::Encryption::Client
- Inherits:
-
Object
- Object
- Auth0::Keys::Encryption::Client
- Defined in:
- lib/auth0/keys/encryption/client.rb
Instance Method Summary collapse
-
#create(request_options: {}, **params) ⇒ Auth0::Types::CreateEncryptionKeyResponseContent
Create the new, pre-activated encryption key, without the key material.
-
#create_public_wrapping_key(request_options: {}, **params) ⇒ Auth0::Types::CreateEncryptionKeyPublicWrappingResponseContent
Create the public wrapping key to wrap your own encryption key material.
-
#delete(request_options: {}, **params) ⇒ untyped
Delete the custom provided encryption key with the given ID and move back to using native encryption key.
-
#get(request_options: {}, **params) ⇒ Auth0::Types::GetEncryptionKeyResponseContent
Retrieve details of the encryption key with the given ID.
-
#import(request_options: {}, **params) ⇒ Auth0::Types::ImportEncryptionKeyResponseContent
Import wrapped key material and activate encryption key.
- #initialize(client:) ⇒ void constructor
-
#list(request_options: {}, **params) ⇒ Auth0::Types::ListEncryptionKeyOffsetPaginatedResponseContent
Retrieve details of all the encryption keys associated with your tenant.
-
#rekey(request_options: {}, **_params) ⇒ untyped
Perform rekeying operation on the key hierarchy.
Constructor Details
#initialize(client:) ⇒ void
10 11 12 |
# File 'lib/auth0/keys/encryption/client.rb', line 10 def initialize(client:) @client = client end |
Instance Method Details
#create(request_options: {}, **params) ⇒ Auth0::Types::CreateEncryptionKeyResponseContent
Create the new, pre-activated encryption key, without the key material.
86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 |
# File 'lib/auth0/keys/encryption/client.rb', line 86 def create(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "POST", path: "keys/encryption", body: Auth0::Keys::Encryption::Types::CreateEncryptionKeyRequestContent.new(params).to_h, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) (response.body.to_s.empty? ? nil : Auth0::Types::CreateEncryptionKeyResponseContent.load(response.body)) else error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#create_public_wrapping_key(request_options: {}, **params) ⇒ Auth0::Types::CreateEncryptionKeyPublicWrappingResponseContent
Create the public wrapping key to wrap your own encryption key material.
274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 |
# File 'lib/auth0/keys/encryption/client.rb', line 274 def create_public_wrapping_key(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "POST", path: "keys/encryption/#{URI.encode_uri_component(params[:kid].to_s)}/wrapping-key", request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) (response.body.to_s.empty? ? nil : Auth0::Types::CreateEncryptionKeyPublicWrappingResponseContent.load(response.body)) else error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#delete(request_options: {}, **params) ⇒ untyped
Delete the custom provided encryption key with the given ID and move back to using native encryption key.
239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 |
# File 'lib/auth0/keys/encryption/client.rb', line 239 def delete(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "DELETE", path: "keys/encryption/#{URI.encode_uri_component(params[:kid].to_s)}", request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i return if code.between?(200, 299) error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end |
#get(request_options: {}, **params) ⇒ Auth0::Types::GetEncryptionKeyResponseContent
Retrieve details of the encryption key with the given ID.
157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 |
# File 'lib/auth0/keys/encryption/client.rb', line 157 def get(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "GET", path: "keys/encryption/#{URI.encode_uri_component(params[:kid].to_s)}", request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) (response.body.to_s.empty? ? nil : Auth0::Types::GetEncryptionKeyResponseContent.load(response.body)) else error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#import(request_options: {}, **params) ⇒ Auth0::Types::ImportEncryptionKeyResponseContent
Import wrapped key material and activate encryption key.
197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 |
# File 'lib/auth0/keys/encryption/client.rb', line 197 def import(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) request_data = Auth0::Keys::Encryption::Types::ImportEncryptionKeyRequestContent.new(params).to_h non_body_param_names = %w[kid] body = request_data.except(*non_body_param_names) request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "POST", path: "keys/encryption/#{URI.encode_uri_component(params[:kid].to_s)}", body: body, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) (response.body.to_s.empty? ? nil : Auth0::Types::ImportEncryptionKeyResponseContent.load(response.body)) else error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#list(request_options: {}, **params) ⇒ Auth0::Types::ListEncryptionKeyOffsetPaginatedResponseContent
Retrieve details of all the encryption keys associated with your tenant.
35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/auth0/keys/encryption/client.rb', line 35 def list(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) query_params = {} query_params["page"] = params.fetch(:page, 0) query_params["per_page"] = params.fetch(:per_page, 50) query_params["include_totals"] = params.fetch(:include_totals, true) Auth0::Internal::OffsetItemIterator.new( initial_page: query_params["page"], item_field: :keys, has_next_field: nil, step: false ) do |next_page| query_params["page"] = next_page request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "GET", path: "keys/encryption", query: query_params, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) parsed_response = (response.body.to_s.empty? ? nil : Auth0::Types::ListEncryptionKeyOffsetPaginatedResponseContent.load(response.body)) [parsed_response, response] else error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end end |
#rekey(request_options: {}, **_params) ⇒ untyped
Perform rekeying operation on the key hierarchy.
123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 |
# File 'lib/auth0/keys/encryption/client.rb', line 123 def rekey(request_options: {}, **_params) request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "POST", path: "keys/encryption/rekey", request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i return if code.between?(200, 299) error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end |