Class: Auth0::NotFound
- Inherits:
-
HTTPError
- Object
- HTTPError
- Auth0::NotFound
- Defined in:
- lib/auth0/exception.rb
Overview
exception for not found resource, you query for an unexistent resource, or wrong path
exception for not found resource, you query for an unexistent resource, or wrong path