Class: Auth0::Organizations::EnabledConnections::Client
- Inherits:
-
Object
- Object
- Auth0::Organizations::EnabledConnections::Client
- Defined in:
- lib/auth0/organizations/enabled_connections/client.rb
Instance Method Summary collapse
-
#add(request_options: {}, **params) ⇒ Auth0::Types::AddOrganizationConnectionResponseContent
Enable a specific connection for a given Organization.
-
#delete(request_options: {}, **params) ⇒ untyped
Disable a specific connection for an Organization.
-
#get(request_options: {}, **params) ⇒ Auth0::Types::GetOrganizationConnectionResponseContent
Retrieve details about a specific connection currently enabled for an Organization.
- #initialize(client:) ⇒ void constructor
-
#list(request_options: {}, **params) ⇒ Auth0::Types::ListOrganizationConnectionsOffsetPaginatedResponseContent
Retrieve details about a specific connection currently enabled for an Organization.
-
#update(request_options: {}, **params) ⇒ Auth0::Types::UpdateOrganizationConnectionResponseContent
Modify the details of a specific connection currently enabled for an Organization.
Constructor Details
#initialize(client:) ⇒ void
10 11 12 |
# File 'lib/auth0/organizations/enabled_connections/client.rb', line 10 def initialize(client:) @client = client end |
Instance Method Details
#add(request_options: {}, **params) ⇒ Auth0::Types::AddOrganizationConnectionResponseContent
Enable a specific connection for a given Organization. To enable a connection, it must already exist within your tenant; connections cannot be created through this action.
Connections represent the relationship between Auth0 and a source of users. Available types of connections include database, enterprise, and social.
98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 |
# File 'lib/auth0/organizations/enabled_connections/client.rb', line 98 def add(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) request_data = Auth0::Organizations::EnabledConnections::Types::AddOrganizationConnectionRequestContent.new(params).to_h non_body_param_names = %w[id] body = request_data.except(*non_body_param_names) request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "POST", path: "organizations/#{URI.encode_uri_component(params[:id].to_s)}/enabled_connections", body: body, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) (response.body.to_s.empty? ? nil : Auth0::Types::AddOrganizationConnectionResponseContent.load(response.body)) else error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#delete(request_options: {}, **params) ⇒ untyped
Disable a specific connection for an Organization. Once disabled, Organization members can no longer use that connection to authenticate.
Note: This action does not remove the connection from your tenant.
190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 |
# File 'lib/auth0/organizations/enabled_connections/client.rb', line 190 def delete(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "DELETE", path: "organizations/#{URI.encode_uri_component(params[:id].to_s)}/enabled_connections/#{URI.encode_uri_component(params[:connection_id].to_s)}", request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i return if code.between?(200, 299) error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end |
#get(request_options: {}, **params) ⇒ Auth0::Types::GetOrganizationConnectionResponseContent
Retrieve details about a specific connection currently enabled for an Organization. Information returned includes details such as connection ID, name, strategy, and whether the connection automatically grants membership upon login.
146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 |
# File 'lib/auth0/organizations/enabled_connections/client.rb', line 146 def get(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "GET", path: "organizations/#{URI.encode_uri_component(params[:id].to_s)}/enabled_connections/#{URI.encode_uri_component(params[:connection_id].to_s)}", request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) (response.body.to_s.empty? ? nil : Auth0::Types::GetOrganizationConnectionResponseContent.load(response.body)) else error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#list(request_options: {}, **params) ⇒ Auth0::Types::ListOrganizationConnectionsOffsetPaginatedResponseContent
Retrieve details about a specific connection currently enabled for an Organization. Information returned includes details such as connection ID, name, strategy, and whether the connection automatically grants membership upon login.
39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/auth0/organizations/enabled_connections/client.rb', line 39 def list(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) query_params = {} query_params["page"] = params.fetch(:page, 0) query_params["per_page"] = params.fetch(:per_page, 50) query_params["include_totals"] = params.fetch(:include_totals, true) Auth0::Internal::OffsetItemIterator.new( initial_page: query_params["page"], item_field: :enabled_connections, has_next_field: nil, step: false ) do |next_page| query_params["page"] = next_page request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "GET", path: "organizations/#{URI.encode_uri_component(params[:id].to_s)}/enabled_connections", query: query_params, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) parsed_response = (response.body.to_s.empty? ? nil : Auth0::Types::ListOrganizationConnectionsOffsetPaginatedResponseContent.load(response.body)) [parsed_response, response] else error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end end |
#update(request_options: {}, **params) ⇒ Auth0::Types::UpdateOrganizationConnectionResponseContent
Modify the details of a specific connection currently enabled for an Organization.
229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 |
# File 'lib/auth0/organizations/enabled_connections/client.rb', line 229 def update(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) request_data = Auth0::Organizations::EnabledConnections::Types::UpdateOrganizationConnectionRequestContent.new(params).to_h non_body_param_names = %w[id connectionId] body = request_data.except(*non_body_param_names) request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "PATCH", path: "organizations/#{URI.encode_uri_component(params[:id].to_s)}/enabled_connections/#{URI.encode_uri_component(params[:connection_id].to_s)}", body: body, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) (response.body.to_s.empty? ? nil : Auth0::Types::UpdateOrganizationConnectionResponseContent.load(response.body)) else error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |