Class: Auth0::Organizations::Roles::Members::Client
- Inherits:
-
Object
- Object
- Auth0::Organizations::Roles::Members::Client
- Defined in:
- lib/auth0/organizations/roles/members/client.rb
Instance Method Summary collapse
- #initialize(client:) ⇒ void constructor
-
#list(request_options: {}, **params) ⇒ Auth0::Types::ListOrganizationRoleMembersResponseContent
List the organization members assigned a specific role within the context of an organization.
Constructor Details
#initialize(client:) ⇒ void
11 12 13 |
# File 'lib/auth0/organizations/roles/members/client.rb', line 11 def initialize(client:) @client = client end |
Instance Method Details
#list(request_options: {}, **params) ⇒ Auth0::Types::ListOrganizationRoleMembersResponseContent
List the organization members assigned a specific role within the context of an organization.
-
Note: Returns only members with direct role assignments. For groups assigned to this role within the
organization, use
GET /api/v2/organizations/{organization_id}/roles/{role_id}/groups.
38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/auth0/organizations/roles/members/client.rb', line 38 def list(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) query_params = {} query_params["from"] = params[:from] if params.key?(:from) query_params["take"] = params.fetch(:take, 50) query_params["fields"] = params[:fields] if params.key?(:fields) query_params["include_fields"] = params.fetch(:include_fields, true) Auth0::Internal::CursorItemIterator.new( cursor_field: :next_, item_field: :members, initial_cursor: query_params["from"] ) do |next_cursor| query_params["from"] = next_cursor request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "GET", path: "organizations/#{URI.encode_uri_component(params[:id].to_s)}/roles/#{URI.encode_uri_component(params[:role_id].to_s)}/members", query: query_params, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) parsed_response = Auth0::Types::ListOrganizationRoleMembersResponseContent.load(response.body) [parsed_response, response] else error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end end |