Class: Auth0::Prompts::CustomText::Client
- Inherits:
-
Object
- Object
- Auth0::Prompts::CustomText::Client
- Defined in:
- lib/auth0/prompts/custom_text/client.rb
Instance Method Summary collapse
-
#get(request_options: {}, **params) ⇒ Hash[String, Object]
Retrieve custom text for a specific prompt and language.
- #initialize(client:) ⇒ void constructor
-
#set(request_options: {}, **params) ⇒ untyped
Set custom text for a specific prompt.
Constructor Details
#initialize(client:) ⇒ void
10 11 12 |
# File 'lib/auth0/prompts/custom_text/client.rb', line 10 def initialize(client:) @client = client end |
Instance Method Details
#get(request_options: {}, **params) ⇒ Hash[String, Object]
Retrieve custom text for a specific prompt and language.
33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 |
# File 'lib/auth0/prompts/custom_text/client.rb', line 33 def get(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "GET", path: "prompts/#{URI.encode_uri_component(params[:prompt].to_s)}/custom-text/#{URI.encode_uri_component(params[:language].to_s)}", request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) (response.body.to_s.empty? ? nil : Auth0::Types::GetCustomTextsByLanguageResponseContent.load(response.body)) else error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#set(request_options: {}, **params) ⇒ untyped
Set custom text for a specific prompt. Existing texts will be overwritten.
77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 |
# File 'lib/auth0/prompts/custom_text/client.rb', line 77 def set(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) path_param_names = %i[prompt language] body_params = params.except(*path_param_names) request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "PUT", path: "prompts/#{URI.encode_uri_component(params[:prompt].to_s)}/custom-text/#{URI.encode_uri_component(params[:language].to_s)}", body: body_params, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i return if code.between?(200, 299) error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end |