Class: Auth0::RiskAssessments::Settings::NewDevice::Client
- Inherits:
-
Object
- Object
- Auth0::RiskAssessments::Settings::NewDevice::Client
- Defined in:
- lib/auth0/risk_assessments/settings/new_device/client.rb
Instance Method Summary collapse
-
#get(request_options: {}, **params) ⇒ Auth0::Types::GetRiskAssessmentsSettingsNewDeviceResponseContent
Gets the risk assessment settings for the new device assessor.
- #initialize(client:) ⇒ void constructor
-
#update(request_options: {}, **params) ⇒ Auth0::Types::UpdateRiskAssessmentsSettingsNewDeviceResponseContent
Updates the risk assessment settings for the new device assessor.
Constructor Details
#initialize(client:) ⇒ void
11 12 13 |
# File 'lib/auth0/risk_assessments/settings/new_device/client.rb', line 11 def initialize(client:) @client = client end |
Instance Method Details
#get(request_options: {}, **params) ⇒ Auth0::Types::GetRiskAssessmentsSettingsNewDeviceResponseContent
Gets the risk assessment settings for the new device assessor
26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 |
# File 'lib/auth0/risk_assessments/settings/new_device/client.rb', line 26 def get(request_options: {}, **params) Auth0::Internal::Types::Utils.normalize_keys(params) request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "GET", path: "risk-assessments/settings/new-device", request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Auth0::Types::GetRiskAssessmentsSettingsNewDeviceResponseContent.load(response.body) else error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#update(request_options: {}, **params) ⇒ Auth0::Types::UpdateRiskAssessmentsSettingsNewDeviceResponseContent
Updates the risk assessment settings for the new device assessor
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/auth0/risk_assessments/settings/new_device/client.rb', line 59 def update(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "PATCH", path: "risk-assessments/settings/new-device", body: Auth0::RiskAssessments::Settings::NewDevice::Types::UpdateRiskAssessmentsSettingsNewDeviceRequestContent.new(params).to_h, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Auth0::Types::UpdateRiskAssessmentsSettingsNewDeviceResponseContent.load(response.body) else error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |