Class: Auth0::Tickets::Client
- Inherits:
-
Object
- Object
- Auth0::Tickets::Client
- Defined in:
- lib/auth0/tickets/client.rb
Instance Method Summary collapse
-
#change_password(request_options: {}, **params) ⇒ Auth0::Types::ChangePasswordTicketResponseContent
Create a password change ticket for a given user.
- #initialize(client:) ⇒ void constructor
-
#verify_email(request_options: {}, **params) ⇒ Auth0::Types::VerifyEmailTicketResponseContent
Create an email verification ticket for a given user.
Constructor Details
#initialize(client:) ⇒ void
9 10 11 |
# File 'lib/auth0/tickets/client.rb', line 9 def initialize(client:) @client = client end |
Instance Method Details
#change_password(request_options: {}, **params) ⇒ Auth0::Types::ChangePasswordTicketResponseContent
Create a password change ticket for a given user. A password change ticket is a generated URL that the user can consume to start a reset password flow.
Note: This endpoint does not verify the given user’s identity. If you call this endpoint within your application, you must design your application to verify the user’s identity.
63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 |
# File 'lib/auth0/tickets/client.rb', line 63 def change_password(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "POST", path: "tickets/password-change", body: Auth0::Tickets::Types::ChangePasswordTicketRequestContent.new(params).to_h, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Auth0::Types::ChangePasswordTicketResponseContent.load(response.body) else error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#verify_email(request_options: {}, **params) ⇒ Auth0::Types::VerifyEmailTicketResponseContent
Create an email verification ticket for a given user. An email verification ticket is a generated URL that the user can consume to verify their email address.
25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 |
# File 'lib/auth0/tickets/client.rb', line 25 def verify_email(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "POST", path: "tickets/email-verification", body: Auth0::Tickets::Types::VerifyEmailTicketRequestContent.new(params).to_h, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Auth0::Types::VerifyEmailTicketResponseContent.load(response.body) else error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |