Class: Auth0::Types::ConnectionOptionsIdpinitiatedSAML
- Inherits:
-
Internal::Types::Model
- Object
- Internal::Types::Model
- Auth0::Types::ConnectionOptionsIdpinitiatedSAML
- Defined in:
- lib/auth0/types/connection_options_idpinitiated_saml.rb
Overview
Configuration for IdP-Initiated SAML Single Sign-On. When enabled, allows users to initiate login directly from their SAML identity provider without first visiting Auth0. The IdP must include the connection parameter in the post-back URL (Assertion Consumer Service URL).
Method Summary
Methods inherited from Internal::Types::Model
#==, ===, add_extra_field_definition, coerce, extra_fields, field, fields, #initialize, #inspect, literal, load, #to_h
Methods included from Internal::Types::Type
Methods included from Internal::JSON::Serializable
Constructor Details
This class inherits a constructor from Auth0::Internal::Types::Model