Class: Auth0::Types::EventStreamCloudEventContext
- Inherits:
-
Internal::Types::Model
- Object
- Internal::Types::Model
- Auth0::Types::EventStreamCloudEventContext
- Defined in:
- lib/auth0/types/event_stream_cloud_event_context.rb
Overview
Information about the context in which the event was produced. This may include things like HTTP request details, client information, connection information, etc.
Note: This field may not be present on all events, depending on the event type and the context in which it was generated.
Method Summary
Methods inherited from Internal::Types::Model
#==, ===, add_extra_field_definition, coerce, extra_fields, field, fields, #initialize, #inspect, literal, load, #to_h
Methods included from Internal::Types::Type
Methods included from Internal::JSON::Serializable
Constructor Details
This class inherits a constructor from Auth0::Internal::Types::Model