Class: Auth0::Types::IntegrationRequiredParam

Inherits:
Internal::Types::Model show all
Defined in:
lib/auth0/types/integration_required_param.rb

Overview

Param are form input values, primarily utilized when specifying secrets and configuration values for actions.

These are especially important for partner integrations – but can be exposed to tenant admins as well if they want to parameterize their custom actions.

Method Summary

Methods inherited from Internal::Types::Model

#==, ===, add_extra_field_definition, coerce, extra_fields, field, fields, #initialize, #inspect, literal, load, #to_h

Methods included from Internal::Types::Type

#coerce, #strict!, #strict?

Methods included from Internal::JSON::Serializable

#dump, #load

Constructor Details

This class inherits a constructor from Auth0::Internal::Types::Model