Class: Auth0::Unauthorized
- Inherits:
-
HTTPError
- Object
- HTTPError
- Auth0::Unauthorized
- Defined in:
- lib/auth0/exception.rb
Overview
exception for unauthorized requests, if you see it, probably Bearer Token is not set correctly
exception for unauthorized requests, if you see it, probably Bearer Token is not set correctly