Class: Auth0::Actions::Triggers::Bindings::Client
- Inherits:
-
Object
- Object
- Auth0::Actions::Triggers::Bindings::Client
- Defined in:
- lib/auth0/actions/triggers/bindings/client.rb
Instance Method Summary collapse
- #initialize(client:) ⇒ void constructor
-
#list(request_options: {}, **params) ⇒ Auth0::Types::ListActionBindingsPaginatedResponseContent
Retrieve the actions that are bound to a trigger.
-
#update_many(request_options: {}, **params) ⇒ Auth0::Types::UpdateActionBindingsResponseContent
Update the actions that are bound (i.e. attached) to a trigger.
Constructor Details
#initialize(client:) ⇒ void
11 12 13 |
# File 'lib/auth0/actions/triggers/bindings/client.rb', line 11 def initialize(client:) @client = client end |
Instance Method Details
#list(request_options: {}, **params) ⇒ Auth0::Types::ListActionBindingsPaginatedResponseContent
Retrieve the actions that are bound to a trigger. Once an action is created and deployed, it must be attached (i.e. bound) to a trigger so that it will be executed as part of a flow. The list of actions returned reflects the order in which they will be executed during the appropriate flow.
31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/auth0/actions/triggers/bindings/client.rb', line 31 def list(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) query_param_names = %i[page per_page] query_params = {} query_params["page"] = params.fetch(:page, 0) query_params["per_page"] = params.fetch(:per_page, 50) params = params.except(*query_param_names) Auth0::Internal::OffsetItemIterator.new( initial_page: query_params["page"], item_field: :bindings, has_next_field: nil, step: true ) do |next_page| query_params["page"] = next_page request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "GET", path: "actions/triggers/#{URI.encode_uri_component(params[:trigger_id].to_s)}/bindings", query: query_params, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Auth0::Types::ListActionBindingsPaginatedResponseContent.load(response.body) else error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end end |
#update_many(request_options: {}, **params) ⇒ Auth0::Types::UpdateActionBindingsResponseContent
Update the actions that are bound (i.e. attached) to a trigger. Once an action is created and deployed, it must be attached (i.e. bound) to a trigger so that it will be executed as part of a flow. The order in which the actions are provided will determine the order in which they are executed.
82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 |
# File 'lib/auth0/actions/triggers/bindings/client.rb', line 82 def update_many(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) request_data = Auth0::Actions::Triggers::Bindings::Types::UpdateActionBindingsRequestContent.new(params).to_h non_body_param_names = ["triggerId"] body = request_data.except(*non_body_param_names) request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "PATCH", path: "actions/triggers/#{URI.encode_uri_component(params[:trigger_id].to_s)}/bindings", body: body, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Auth0::Types::UpdateActionBindingsResponseContent.load(response.body) else error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |