Class: Auth0::Actions::Versions::Client
- Inherits:
-
Object
- Object
- Auth0::Actions::Versions::Client
- Defined in:
- lib/auth0/actions/versions/client.rb
Instance Method Summary collapse
-
#deploy(request_options: {}, **params) ⇒ Auth0::Types::DeployActionVersionResponseContent
Performs the equivalent of a roll-back of an action to an earlier, specified version.
-
#get(request_options: {}, **params) ⇒ Auth0::Types::GetActionVersionResponseContent
Retrieve a specific version of an action.
- #initialize(client:) ⇒ void constructor
-
#list(request_options: {}, **params) ⇒ Auth0::Types::ListActionVersionsPaginatedResponseContent
Retrieve all of an action’s versions.
Constructor Details
#initialize(client:) ⇒ void
10 11 12 |
# File 'lib/auth0/actions/versions/client.rb', line 10 def initialize(client:) @client = client end |
Instance Method Details
#deploy(request_options: {}, **params) ⇒ Auth0::Types::DeployActionVersionResponseContent
Performs the equivalent of a roll-back of an action to an earlier, specified version. Creates a new, deployed action version that is identical to the specified version. If this action is currently bound to a trigger, the system will begin executing the newly-created version immediately.
116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 |
# File 'lib/auth0/actions/versions/client.rb', line 116 def deploy(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "POST", path: "actions/actions/#{URI.encode_uri_component(params[:action_id].to_s)}/versions/#{URI.encode_uri_component(params[:id].to_s)}/deploy", body: params, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Auth0::Types::DeployActionVersionResponseContent.load(response.body) else error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#get(request_options: {}, **params) ⇒ Auth0::Types::GetActionVersionResponseContent
Retrieve a specific version of an action. An action version is created whenever an action is deployed. An action version is immutable, once created.
79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 |
# File 'lib/auth0/actions/versions/client.rb', line 79 def get(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "GET", path: "actions/actions/#{URI.encode_uri_component(params[:action_id].to_s)}/versions/#{URI.encode_uri_component(params[:id].to_s)}", request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Auth0::Types::GetActionVersionResponseContent.load(response.body) else error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#list(request_options: {}, **params) ⇒ Auth0::Types::ListActionVersionsPaginatedResponseContent
Retrieve all of an action’s versions. An action version is created whenever an action is deployed. An action version is immutable, once created.
29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 |
# File 'lib/auth0/actions/versions/client.rb', line 29 def list(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) query_params = {} query_params["page"] = params.fetch(:page, 0) query_params["per_page"] = params.fetch(:per_page, 50) Auth0::Internal::OffsetItemIterator.new( initial_page: query_params["page"], item_field: :versions, has_next_field: nil, step: false ) do |next_page| query_params["page"] = next_page request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "GET", path: "actions/actions/#{URI.encode_uri_component(params[:action_id].to_s)}/versions", query: query_params, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) parsed_response = Auth0::Types::ListActionVersionsPaginatedResponseContent.load(response.body) [parsed_response, response] else error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end end |