Class: Auth0::Actions::Versions::Client
- Inherits:
-
Object
- Object
- Auth0::Actions::Versions::Client
- Defined in:
- lib/auth0/actions/versions/client.rb
Instance Method Summary collapse
-
#deploy(request_options: {}, **params) ⇒ Auth0::Types::DeployActionVersionResponseContent
Performs the equivalent of a roll-back of an action to an earlier, specified version.
-
#get(request_options: {}, **params) ⇒ Auth0::Types::GetActionVersionResponseContent
Retrieve a specific version of an action.
- #initialize(client:) ⇒ void constructor
-
#list(request_options: {}, **params) ⇒ Auth0::Types::ListActionVersionsPaginatedResponseContent
Retrieve all of an action's versions.
Constructor Details
#initialize(client:) ⇒ void
10 11 12 |
# File 'lib/auth0/actions/versions/client.rb', line 10 def initialize(client:) @client = client end |
Instance Method Details
#deploy(request_options: {}, **params) ⇒ Auth0::Types::DeployActionVersionResponseContent
Performs the equivalent of a roll-back of an action to an earlier, specified version. Creates a new, deployed action version that is identical to the specified version. If this action is currently bound to a trigger, the system will begin executing the newly-created version immediately.
136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 |
# File 'lib/auth0/actions/versions/client.rb', line 136 def deploy(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) path_param_names = %i[action_id id] body_params = params.except(*path_param_names) request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "POST", path: "actions/actions/#{URI.encode_uri_component(params[:action_id].to_s)}/versions/#{URI.encode_uri_component(params[:id].to_s)}/deploy", body: body_params, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) (response.body.to_s.empty? ? nil : Auth0::Types::DeployActionVersionResponseContent.load(response.body)) else error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#get(request_options: {}, **params) ⇒ Auth0::Types::GetActionVersionResponseContent
Retrieve a specific version of an action. An action version is created whenever an action is deployed. An action version is immutable, once created.
92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 |
# File 'lib/auth0/actions/versions/client.rb', line 92 def get(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "GET", path: "actions/actions/#{URI.encode_uri_component(params[:action_id].to_s)}/versions/#{URI.encode_uri_component(params[:id].to_s)}", request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) (response.body.to_s.empty? ? nil : Auth0::Types::GetActionVersionResponseContent.load(response.body)) else error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#list(request_options: {}, **params) ⇒ Auth0::Types::ListActionVersionsPaginatedResponseContent
Retrieve all of an action's versions. An action version is created whenever an action is deployed. An action version is immutable, once created.
36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/auth0/actions/versions/client.rb', line 36 def list(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) query_params = {} query_params["page"] = params.fetch(:page, 0) query_params["per_page"] = params.fetch(:per_page, 50) Auth0::Internal::OffsetItemIterator.new( initial_page: query_params["page"], item_field: :versions, has_next_field: nil, step: false ) do |next_page| query_params["page"] = next_page request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "GET", path: "actions/actions/#{URI.encode_uri_component(params[:action_id].to_s)}/versions", query: query_params, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) parsed_response = (response.body.to_s.empty? ? nil : Auth0::Types::ListActionVersionsPaginatedResponseContent.load(response.body)) [parsed_response, response] else error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end end |