Class: Auth0::Branding::Phone::Providers::Client
- Inherits:
-
Object
- Object
- Auth0::Branding::Phone::Providers::Client
- Defined in:
- lib/auth0/branding/phone/providers/client.rb
Instance Method Summary collapse
-
#create(request_options: {}, **params) ⇒ Auth0::Types::CreateBrandingPhoneProviderResponseContent
Create a <a href=“auth0.com/docs/customize/phone-messages/configure-phone-messaging-providers”>phone provider</a>.
-
#delete(request_options: {}, **params) ⇒ untyped
Delete the configured phone provider.
-
#get(request_options: {}, **params) ⇒ Auth0::Types::GetBrandingPhoneProviderResponseContent
Retrieve <a href=“auth0.com/docs/customize/phone-messages/configure-phone-messaging-providers”>phone provider</a> details.
- #initialize(client:) ⇒ void constructor
-
#list(request_options: {}, **params) ⇒ Auth0::Types::ListBrandingPhoneProvidersResponseContent
Retrieve a list of <a href=“auth0.com/docs/customize/phone-messages/configure-phone-messaging-providers”>phone providers</a> details set for a Tenant.
- #test(request_options: {}, **params) ⇒ Auth0::Types::CreatePhoneProviderSendTestResponseContent
-
#update(request_options: {}, **params) ⇒ Auth0::Types::UpdateBrandingPhoneProviderResponseContent
Update a <a href=“auth0.com/docs/customize/phone-messages/configure-phone-messaging-providers”>phone provider</a>.
Constructor Details
#initialize(client:) ⇒ void
11 12 13 |
# File 'lib/auth0/branding/phone/providers/client.rb', line 11 def initialize(client:) @client = client end |
Instance Method Details
#create(request_options: {}, **params) ⇒ Auth0::Types::CreateBrandingPhoneProviderResponseContent
Create a <a href=“auth0.com/docs/customize/phone-messages/configure-phone-messaging-providers”>phone provider</a>. The credentials object requires different properties depending on the phone provider (which is specified using the name property).
71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 |
# File 'lib/auth0/branding/phone/providers/client.rb', line 71 def create(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "POST", path: "branding/phone/providers", body: Auth0::Branding::Phone::Providers::Types::CreateBrandingPhoneProviderRequestContent.new(params).to_h, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Auth0::Types::CreateBrandingPhoneProviderResponseContent.load(response.body) else error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#delete(request_options: {}, **params) ⇒ untyped
Delete the configured phone provider.
141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 |
# File 'lib/auth0/branding/phone/providers/client.rb', line 141 def delete(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "DELETE", path: "branding/phone/providers/#{URI.encode_uri_component(params[:id].to_s)}", request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i return if code.between?(200, 299) error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end |
#get(request_options: {}, **params) ⇒ Auth0::Types::GetBrandingPhoneProviderResponseContent
Retrieve <a href=“auth0.com/docs/customize/phone-messages/configure-phone-messaging-providers”>phone provider</a> details. A list of fields to include or exclude may also be specified.
107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 |
# File 'lib/auth0/branding/phone/providers/client.rb', line 107 def get(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "GET", path: "branding/phone/providers/#{URI.encode_uri_component(params[:id].to_s)}", request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Auth0::Types::GetBrandingPhoneProviderResponseContent.load(response.body) else error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#list(request_options: {}, **params) ⇒ Auth0::Types::ListBrandingPhoneProvidersResponseContent
Retrieve a list of <a href=“auth0.com/docs/customize/phone-messages/configure-phone-messaging-providers”>phone providers</a> details set for a Tenant. A list of fields to include or exclude may also be specified.
29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 |
# File 'lib/auth0/branding/phone/providers/client.rb', line 29 def list(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) query_param_names = %i[disabled] query_params = {} query_params["disabled"] = params[:disabled] if params.key?(:disabled) params.except(*query_param_names) request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "GET", path: "branding/phone/providers", query: query_params, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Auth0::Types::ListBrandingPhoneProvidersResponseContent.load(response.body) else error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#test(request_options: {}, **params) ⇒ Auth0::Types::CreatePhoneProviderSendTestResponseContent
213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 |
# File 'lib/auth0/branding/phone/providers/client.rb', line 213 def test(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) request_data = Auth0::Branding::Phone::Providers::Types::CreatePhoneProviderSendTestRequestContent.new(params).to_h non_body_param_names = ["id"] body = request_data.except(*non_body_param_names) request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "POST", path: "branding/phone/providers/#{URI.encode_uri_component(params[:id].to_s)}/try", body: body, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Auth0::Types::CreatePhoneProviderSendTestResponseContent.load(response.body) else error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#update(request_options: {}, **params) ⇒ Auth0::Types::UpdateBrandingPhoneProviderResponseContent
Update a <a href=“auth0.com/docs/customize/phone-messages/configure-phone-messaging-providers”>phone provider</a>. The credentials object requires different properties depending on the phone provider (which is specified using the name property).
176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 |
# File 'lib/auth0/branding/phone/providers/client.rb', line 176 def update(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) request_data = Auth0::Branding::Phone::Providers::Types::UpdateBrandingPhoneProviderRequestContent.new(params).to_h non_body_param_names = ["id"] body = request_data.except(*non_body_param_names) request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "PATCH", path: "branding/phone/providers/#{URI.encode_uri_component(params[:id].to_s)}", body: body, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Auth0::Types::UpdateBrandingPhoneProviderResponseContent.load(response.body) else error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |