Class: Auth0::ClientGrants::Client
- Inherits:
-
Object
- Object
- Auth0::ClientGrants::Client
- Defined in:
- lib/auth0/client_grants/client.rb
Instance Method Summary collapse
-
#create(request_options: {}, **params) ⇒ Auth0::Types::CreateClientGrantResponseContent
Create a client grant for a machine-to-machine login flow.
-
#delete(request_options: {}, **params) ⇒ untyped
Delete the Client Credential Flow from your machine-to-machine application.
-
#get(request_options: {}, **params) ⇒ Auth0::Types::GetClientGrantResponseContent
Retrieve a single client grant, including the scopes associated with the application/API pair.
- #initialize(client:) ⇒ void constructor
-
#list(request_options: {}, **params) ⇒ Auth0::Types::ListClientGrantPaginatedResponseContent
Retrieve a list of client grants, including the scopes associated with the application/API pair.
- #organizations ⇒ Auth0::Organizations::Client
-
#update(request_options: {}, **params) ⇒ Auth0::Types::UpdateClientGrantResponseContent
Update a client grant.
Constructor Details
#initialize(client:) ⇒ void
9 10 11 |
# File 'lib/auth0/client_grants/client.rb', line 9 def initialize(client:) @client = client end |
Instance Method Details
#create(request_options: {}, **params) ⇒ Auth0::Types::CreateClientGrantResponseContent
Create a client grant for a machine-to-machine login flow. To learn more, read Client Credential Flow.
87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 |
# File 'lib/auth0/client_grants/client.rb', line 87 def create(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "POST", path: "client-grants", body: Auth0::ClientGrants::Types::CreateClientGrantRequestContent.new(params).to_h, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Auth0::Types::CreateClientGrantResponseContent.load(response.body) else error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#delete(request_options: {}, **params) ⇒ untyped
Delete the Client Credential Flow from your machine-to-machine application.
160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 |
# File 'lib/auth0/client_grants/client.rb', line 160 def delete(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "DELETE", path: "client-grants/#{URI.encode_uri_component(params[:id].to_s)}", request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i return if code.between?(200, 299) error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end |
#get(request_options: {}, **params) ⇒ Auth0::Types::GetClientGrantResponseContent
Retrieve a single client grant, including the scopes associated with the application/API pair.
124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 |
# File 'lib/auth0/client_grants/client.rb', line 124 def get(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "GET", path: "client-grants/#{URI.encode_uri_component(params[:id].to_s)}", request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Auth0::Types::GetClientGrantResponseContent.load(response.body) else error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#list(request_options: {}, **params) ⇒ Auth0::Types::ListClientGrantPaginatedResponseContent
Retrieve a list of client grants, including the scopes associated with the application/API pair.
34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/auth0/client_grants/client.rb', line 34 def list(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) query_params = {} query_params["include_totals"] = params.fetch(:include_totals, true) query_params["from"] = params[:from] if params.key?(:from) query_params["take"] = params.fetch(:take, 50) query_params["audience"] = params[:audience] if params.key?(:audience) query_params["client_id"] = params[:client_id] if params.key?(:client_id) query_params["allow_any_organization"] = params[:allow_any_organization] if params.key?(:allow_any_organization) query_params["subject_type"] = params[:subject_type] if params.key?(:subject_type) query_params["default_for"] = params[:default_for] if params.key?(:default_for) Auth0::Internal::CursorItemIterator.new( cursor_field: :next_, item_field: :client_grants, initial_cursor: query_params["from"] ) do |next_cursor| query_params["from"] = next_cursor request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "GET", path: "client-grants", query: query_params, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) parsed_response = Auth0::Types::ListClientGrantPaginatedResponseContent.load(response.body) [parsed_response, response] else error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end end |
#organizations ⇒ Auth0::Organizations::Client
220 221 222 |
# File 'lib/auth0/client_grants/client.rb', line 220 def organizations @organizations ||= Auth0::ClientGrants::Organizations::Client.new(client: @client) end |
#update(request_options: {}, **params) ⇒ Auth0::Types::UpdateClientGrantResponseContent
Update a client grant.
192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 |
# File 'lib/auth0/client_grants/client.rb', line 192 def update(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) request_data = Auth0::ClientGrants::Types::UpdateClientGrantRequestContent.new(params).to_h non_body_param_names = %w[id] body = request_data.except(*non_body_param_names) request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "PATCH", path: "client-grants/#{URI.encode_uri_component(params[:id].to_s)}", body: body, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Auth0::Types::UpdateClientGrantResponseContent.load(response.body) else error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |