Class: Auth0::Clients::Connections::Client
- Inherits:
-
Object
- Object
- Auth0::Clients::Connections::Client
- Defined in:
- lib/auth0/clients/connections/client.rb
Instance Method Summary collapse
-
#get(request_options: {}, **params) ⇒ Auth0::Types::ListClientConnectionsResponseContent
Retrieve all connections that are enabled for the specified [Application](www.auth0.com/docs/get-started/applications), using checkpoint pagination.
- #initialize(client:) ⇒ void constructor
Constructor Details
#initialize(client:) ⇒ void
10 11 12 |
# File 'lib/auth0/clients/connections/client.rb', line 10 def initialize(client:) @client = client end |
Instance Method Details
#get(request_options: {}, **params) ⇒ Auth0::Types::ListClientConnectionsResponseContent
Retrieve all connections that are enabled for the specified [Application](www.auth0.com/docs/get-started/applications), using checkpoint pagination. A list of fields to include or exclude for each connection may also be specified.
-
This endpoint requires the ‘read:connections` scope and any one of `read:clients` or `read:client_summary`.
-
Note: The first time you call this endpoint, omit the ‘from` parameter. If there are more results, a
‘next` value is included in the response. You can use this for subsequent API calls. When `next` is no longer included in the response, no further results are remaining.
38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/auth0/clients/connections/client.rb', line 38 def get(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) query_params = {} query_params["strategy"] = params[:strategy] if params.key?(:strategy) query_params["from"] = params[:from] if params.key?(:from) query_params["take"] = params.fetch(:take, 50) query_params["fields"] = params[:fields] if params.key?(:fields) query_params["include_fields"] = params[:include_fields] if params.key?(:include_fields) Auth0::Internal::CursorItemIterator.new( cursor_field: :next_, item_field: :connections, initial_cursor: query_params["from"] ) do |next_cursor| query_params["from"] = next_cursor request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "GET", path: "clients/#{URI.encode_uri_component(params[:id].to_s)}/connections", query: query_params, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) parsed_response = Auth0::Types::ListClientConnectionsResponseContent.load(response.body) [parsed_response, response] else error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end end |