Class: Auth0::Connections::Clients::Client
- Inherits:
-
Object
- Object
- Auth0::Connections::Clients::Client
- Defined in:
- lib/auth0/connections/clients/client.rb
Instance Method Summary collapse
-
#get(request_options: {}, **params) ⇒ Auth0::Types::GetConnectionEnabledClientsResponseContent
Retrieve all clients that have the specified <a href=“auth0.com/docs/authenticate/identity-providers”>connection</a> enabled.
- #initialize(client:) ⇒ void constructor
- #update(request_options: {}, **params) ⇒ untyped
Constructor Details
#initialize(client:) ⇒ void
10 11 12 |
# File 'lib/auth0/connections/clients/client.rb', line 10 def initialize(client:) @client = client end |
Instance Method Details
#get(request_options: {}, **params) ⇒ Auth0::Types::GetConnectionEnabledClientsResponseContent
Retrieve all clients that have the specified <a href=“auth0.com/docs/authenticate/identity-providers”>connection</a> enabled.
Note: The first time you call this endpoint, omit the from parameter. If there are more results, a next value is included in the response. You can use this for subsequent API calls. When next is no longer included in the response, no further results are remaining.
33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 |
# File 'lib/auth0/connections/clients/client.rb', line 33 def get(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) query_param_names = %i[take from] query_params = {} query_params["take"] = params.fetch(:take, 50) query_params["from"] = params[:from] if params.key?(:from) params = params.except(*query_param_names) Auth0::Internal::CursorItemIterator.new( cursor_field: :next_, item_field: :clients, initial_cursor: query_params["from"] ) do |next_cursor| query_params["from"] = next_cursor request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "GET", path: "connections/#{URI.encode_uri_component(params[:id].to_s)}/clients", query: query_params, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Auth0::Types::GetConnectionEnabledClientsResponseContent.load(response.body) else error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end end |
#update(request_options: {}, **params) ⇒ untyped
79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'lib/auth0/connections/clients/client.rb', line 79 def update(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "PATCH", path: "connections/#{URI.encode_uri_component(params[:id].to_s)}/clients", body: params, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i return if code.between?(200, 299) error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end |