Class: Auth0::Connections::DirectoryProvisioning::Client
- Inherits:
-
Object
- Object
- Auth0::Connections::DirectoryProvisioning::Client
- Defined in:
- lib/auth0/connections/directory_provisioning/client.rb
Instance Method Summary collapse
-
#create(request_options: {}, **params) ⇒ Auth0::Types::CreateDirectoryProvisioningResponseContent
Create a directory provisioning configuration for a connection.
-
#delete(request_options: {}, **params) ⇒ untyped
Delete the directory provisioning configuration of a connection.
-
#get(request_options: {}, **params) ⇒ Auth0::Types::GetDirectoryProvisioningResponseContent
Retrieve the directory provisioning configuration of a connection.
-
#get_default_mapping(request_options: {}, **params) ⇒ Auth0::Types::GetDirectoryProvisioningDefaultMappingResponseContent
Retrieve the directory provisioning default attribute mapping of a connection.
- #initialize(client:) ⇒ void constructor
-
#list(request_options: {}, **params) ⇒ Auth0::Types::ListDirectoryProvisioningsResponseContent
Retrieve a list of directory provisioning configurations of a tenant.
-
#list_synchronized_groups(request_options: {}, **params) ⇒ Auth0::Types::ListSynchronizedGroupsResponseContent
Retrieve the configured synchronized groups for a connection directory provisioning configuration.
-
#set(request_options: {}, **params) ⇒ untyped
Create or replace the selected groups for a connection directory provisioning configuration.
- #synchronizations ⇒ Auth0::Synchronizations::Client
-
#update(request_options: {}, **params) ⇒ Auth0::Types::UpdateDirectoryProvisioningResponseContent
Update the directory provisioning configuration of a connection.
Constructor Details
#initialize(client:) ⇒ void
10 11 12 |
# File 'lib/auth0/connections/directory_provisioning/client.rb', line 10 def initialize(client:) @client = client end |
Instance Method Details
#create(request_options: {}, **params) ⇒ Auth0::Types::CreateDirectoryProvisioningResponseContent
Create a directory provisioning configuration for a connection.
109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 |
# File 'lib/auth0/connections/directory_provisioning/client.rb', line 109 def create(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "POST", path: "connections/#{URI.encode_uri_component(params[:id].to_s)}/directory-provisioning", body: params, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Auth0::Types::CreateDirectoryProvisioningResponseContent.load(response.body) else error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#delete(request_options: {}, **params) ⇒ untyped
Delete the directory provisioning configuration of a connection.
144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 |
# File 'lib/auth0/connections/directory_provisioning/client.rb', line 144 def delete(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "DELETE", path: "connections/#{URI.encode_uri_component(params[:id].to_s)}/directory-provisioning", request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i return if code.between?(200, 299) error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end |
#get(request_options: {}, **params) ⇒ Auth0::Types::GetDirectoryProvisioningResponseContent
Retrieve the directory provisioning configuration of a connection.
75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 |
# File 'lib/auth0/connections/directory_provisioning/client.rb', line 75 def get(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "GET", path: "connections/#{URI.encode_uri_component(params[:id].to_s)}/directory-provisioning", request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Auth0::Types::GetDirectoryProvisioningResponseContent.load(response.body) else error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#get_default_mapping(request_options: {}, **params) ⇒ Auth0::Types::GetDirectoryProvisioningDefaultMappingResponseContent
Retrieve the directory provisioning default attribute mapping of a connection.
211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 |
# File 'lib/auth0/connections/directory_provisioning/client.rb', line 211 def get_default_mapping(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "GET", path: "connections/#{URI.encode_uri_component(params[:id].to_s)}/directory-provisioning/default-mapping", request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Auth0::Types::GetDirectoryProvisioningDefaultMappingResponseContent.load(response.body) else error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#list(request_options: {}, **params) ⇒ Auth0::Types::ListDirectoryProvisioningsResponseContent
Retrieve a list of directory provisioning configurations of a tenant.
27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 |
# File 'lib/auth0/connections/directory_provisioning/client.rb', line 27 def list(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) query_param_names = %i[from take] query_params = {} query_params["from"] = params[:from] if params.key?(:from) query_params["take"] = params.fetch(:take, 50) params.except(*query_param_names) Auth0::Internal::CursorItemIterator.new( cursor_field: :next_, item_field: :directory_provisionings, initial_cursor: query_params["from"] ) do |next_cursor| query_params["from"] = next_cursor request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "GET", path: "connections-directory-provisionings", query: query_params, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Auth0::Types::ListDirectoryProvisioningsResponseContent.load(response.body) else error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end end |
#list_synchronized_groups(request_options: {}, **params) ⇒ Auth0::Types::ListSynchronizedGroupsResponseContent
Retrieve the configured synchronized groups for a connection directory provisioning configuration.
247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 |
# File 'lib/auth0/connections/directory_provisioning/client.rb', line 247 def list_synchronized_groups(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) query_param_names = %i[from take] query_params = {} query_params["from"] = params[:from] if params.key?(:from) query_params["take"] = params.fetch(:take, 50) params = params.except(*query_param_names) Auth0::Internal::CursorItemIterator.new( cursor_field: :next_, item_field: :groups, initial_cursor: query_params["from"] ) do |next_cursor| query_params["from"] = next_cursor request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "GET", path: "connections/#{URI.encode_uri_component(params[:id].to_s)}/directory-provisioning/synchronized-groups", query: query_params, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Auth0::Types::ListSynchronizedGroupsResponseContent.load(response.body) else error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end end |
#set(request_options: {}, **params) ⇒ untyped
Create or replace the selected groups for a connection directory provisioning configuration.
295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 |
# File 'lib/auth0/connections/directory_provisioning/client.rb', line 295 def set(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) request_data = Auth0::Connections::DirectoryProvisioning::Types::ReplaceSynchronizedGroupsRequestContent.new(params).to_h non_body_param_names = ["id"] body = request_data.except(*non_body_param_names) request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "PUT", path: "connections/#{URI.encode_uri_component(params[:id].to_s)}/directory-provisioning/synchronized-groups", body: body, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i return if code.between?(200, 299) error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end |
#synchronizations ⇒ Auth0::Synchronizations::Client
321 322 323 |
# File 'lib/auth0/connections/directory_provisioning/client.rb', line 321 def synchronizations @synchronizations ||= Auth0::Connections::DirectoryProvisioning::Synchronizations::Client.new(client: @client) end |
#update(request_options: {}, **params) ⇒ Auth0::Types::UpdateDirectoryProvisioningResponseContent
Update the directory provisioning configuration of a connection.
176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 |
# File 'lib/auth0/connections/directory_provisioning/client.rb', line 176 def update(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "PATCH", path: "connections/#{URI.encode_uri_component(params[:id].to_s)}/directory-provisioning", body: params, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Auth0::Types::UpdateDirectoryProvisioningResponseContent.load(response.body) else error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |