Class: Auth0::Connections::Keys::Client
- Inherits:
-
Object
- Object
- Auth0::Connections::Keys::Client
- Defined in:
- lib/auth0/connections/keys/client.rb
Instance Method Summary collapse
-
#create(request_options: {}, **params) ⇒ Array[Auth0::Types::PostConnectionsKeysResponseContentItem]
Provision initial connection keys for Okta or OIDC connection strategies.
-
#get(request_options: {}, **params) ⇒ Array[Auth0::Types::ConnectionKey]
Gets the connection keys for the Okta or OIDC connection strategy.
- #initialize(client:) ⇒ void constructor
-
#rotate(request_options: {}, **params) ⇒ Auth0::Types::RotateConnectionsKeysResponseContent
Rotates the connection keys for the Okta or OIDC connection strategies.
Constructor Details
#initialize(client:) ⇒ void
10 11 12 |
# File 'lib/auth0/connections/keys/client.rb', line 10 def initialize(client:) @client = client end |
Instance Method Details
#create(request_options: {}, **params) ⇒ Array[Auth0::Types::PostConnectionsKeysResponseContentItem]
Provision initial connection keys for Okta or OIDC connection strategies. This endpoint allows you to create keys before configuring the connection to use Private Key JWT authentication, enabling zero-downtime transitions.
60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/auth0/connections/keys/client.rb', line 60 def create(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "POST", path: "connections/#{URI.encode_uri_component(params[:id].to_s)}/keys", body: params, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Auth0::Types::PostConnectionsKeysResponseContent.load(response.body) else error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#get(request_options: {}, **params) ⇒ Array[Auth0::Types::ConnectionKey]
Gets the connection keys for the Okta or OIDC connection strategy.
26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 |
# File 'lib/auth0/connections/keys/client.rb', line 26 def get(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "GET", path: "connections/#{URI.encode_uri_component(params[:id].to_s)}/keys", request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i return if code.between?(200, 299) error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end |
#rotate(request_options: {}, **params) ⇒ Auth0::Types::RotateConnectionsKeysResponseContent
Rotates the connection keys for the Okta or OIDC connection strategies.
95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 |
# File 'lib/auth0/connections/keys/client.rb', line 95 def rotate(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "POST", path: "connections/#{URI.encode_uri_component(params[:id].to_s)}/keys/rotate", body: params, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Auth0::Types::RotateConnectionsKeysResponseContent.load(response.body) else error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |