Class: Auth0::Connections::Keys::Client
- Inherits:
-
Object
- Object
- Auth0::Connections::Keys::Client
- Defined in:
- lib/auth0/connections/keys/client.rb
Instance Method Summary collapse
-
#create(request_options: {}, **params) ⇒ Array[Auth0::Types::PostConnectionsKeysResponseContentItem]
Provision initial connection keys for Okta or OIDC connection strategies.
-
#get(request_options: {}, **params) ⇒ Array[Auth0::Types::ConnectionKey]
Gets the connection keys for the Okta or OIDC connection strategy.
- #initialize(client:) ⇒ void constructor
-
#rotate(request_options: {}, **params) ⇒ Auth0::Types::RotateConnectionsKeysResponseContent
Rotates the connection keys for the Okta or OIDC connection strategies.
Constructor Details
#initialize(client:) ⇒ void
10 11 12 |
# File 'lib/auth0/connections/keys/client.rb', line 10 def initialize(client:) @client = client end |
Instance Method Details
#create(request_options: {}, **params) ⇒ Array[Auth0::Types::PostConnectionsKeysResponseContentItem]
Provision initial connection keys for Okta or OIDC connection strategies. This endpoint allows you to create keys before configuring the connection to use Private Key JWT authentication, enabling zero-downtime transitions.
71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 |
# File 'lib/auth0/connections/keys/client.rb', line 71 def create(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) path_param_names = %i[id] body_params = params.except(*path_param_names) request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "POST", path: "connections/#{URI.encode_uri_component(params[:id].to_s)}/keys", body: body_params, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) (response.body.to_s.empty? ? nil : Auth0::Types::PostConnectionsKeysResponseContent.load(response.body)) else error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#get(request_options: {}, **params) ⇒ Array[Auth0::Types::ConnectionKey]
Gets the connection keys for the Okta or OIDC connection strategy.
29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 |
# File 'lib/auth0/connections/keys/client.rb', line 29 def get(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "GET", path: "connections/#{URI.encode_uri_component(params[:id].to_s)}/keys", request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Auth0::Internal::Types::Utils.coerce(Internal::Types::Array[Auth0::Types::ConnectionKey], (response.body.to_s.empty? ? nil : JSON.parse(response.body, symbolize_names: true))) else error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#rotate(request_options: {}, **params) ⇒ Auth0::Types::RotateConnectionsKeysResponseContent
Rotates the connection keys for the Okta or OIDC connection strategies.
115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 |
# File 'lib/auth0/connections/keys/client.rb', line 115 def rotate(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) path_param_names = %i[id] body_params = params.except(*path_param_names) request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "POST", path: "connections/#{URI.encode_uri_component(params[:id].to_s)}/keys/rotate", body: body_params, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) (response.body.to_s.empty? ? nil : Auth0::Types::RotateConnectionsKeysResponseContent.load(response.body)) else error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |