Class: Auth0::Guardian::Enrollments::Client
- Inherits:
-
Object
- Object
- Auth0::Guardian::Enrollments::Client
- Defined in:
- lib/auth0/guardian/enrollments/client.rb
Instance Method Summary collapse
-
#create_ticket(request_options: {}, **params) ⇒ Auth0::Types::CreateGuardianEnrollmentTicketResponseContent
Create a <a href=“auth0.com/docs/secure/multi-factor-authentication/auth0-guardian/create-custom-enrollment-tickets”>multi-factor authentication (MFA) enrollment ticket</a>, and optionally send an email with the created ticket, to a given user.
-
#delete(request_options: {}, **params) ⇒ untyped
Remove a specific multi-factor authentication (MFA) enrollment from a user’s account.
-
#get(request_options: {}, **params) ⇒ Auth0::Types::GetGuardianEnrollmentResponseContent
Retrieve details, such as status and type, for a specific multi-factor authentication enrollment registered to a user account.
- #initialize(client:) ⇒ void constructor
Constructor Details
#initialize(client:) ⇒ void
10 11 12 |
# File 'lib/auth0/guardian/enrollments/client.rb', line 10 def initialize(client:) @client = client end |
Instance Method Details
#create_ticket(request_options: {}, **params) ⇒ Auth0::Types::CreateGuardianEnrollmentTicketResponseContent
Create a <a href=“auth0.com/docs/secure/multi-factor-authentication/auth0-guardian/create-custom-enrollment-tickets”>multi-factor authentication (MFA) enrollment ticket</a>, and optionally send an email with the created ticket, to a given user. Create a <a href=“auth0.com/docs/secure/multi-factor-authentication/auth0-guardian/create-custom-enrollment-tickets”>multi-factor authentication (MFA) enrollment ticket</a>, and optionally send an email with the created ticket to a given user. Enrollment tickets can specify which factor users must enroll with or allow existing MFA users to enroll in additional factors.<br/>
Note: Users cannot enroll in Email as a factor through custom enrollment tickets.
35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 |
# File 'lib/auth0/guardian/enrollments/client.rb', line 35 def create_ticket(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "POST", path: "guardian/enrollments/ticket", body: Auth0::Guardian::Enrollments::Types::CreateGuardianEnrollmentTicketRequestContent.new(params).to_h, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Auth0::Types::CreateGuardianEnrollmentTicketResponseContent.load(response.body) else error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#delete(request_options: {}, **params) ⇒ untyped
Remove a specific multi-factor authentication (MFA) enrollment from a user’s account. This allows the user to re-enroll with MFA. For more information, review <a href=“auth0.com/docs/secure/multi-factor-authentication/reset-user-mfa”>Reset User Multi-Factor Authentication and Recovery Codes</a>.
108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 |
# File 'lib/auth0/guardian/enrollments/client.rb', line 108 def delete(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "DELETE", path: "guardian/enrollments/#{URI.encode_uri_component(params[:id].to_s)}", request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i return if code.between?(200, 299) error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end |
#get(request_options: {}, **params) ⇒ Auth0::Types::GetGuardianEnrollmentResponseContent
Retrieve details, such as status and type, for a specific multi-factor authentication enrollment registered to a user account.
71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 |
# File 'lib/auth0/guardian/enrollments/client.rb', line 71 def get(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "GET", path: "guardian/enrollments/#{URI.encode_uri_component(params[:id].to_s)}", request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Auth0::Types::GetGuardianEnrollmentResponseContent.load(response.body) else error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |