Class: Auth0::Guardian::Factors::Phone::Client
- Inherits:
-
Object
- Object
- Auth0::Guardian::Factors::Phone::Client
- Defined in:
- lib/auth0/guardian/factors/phone/client.rb
Instance Method Summary collapse
-
#get_message_types(request_options: {}, **params) ⇒ Auth0::Types::GetGuardianFactorPhoneMessageTypesResponseContent
Retrieve list of <a href=“auth0.com/docs/secure/multi-factor-authentication/multi-factor-authentication-factors/configure-sms-voice-notifications-mfa”>phone-type MFA factors</a> (i.e., sms and voice) that are enabled for your tenant.
-
#get_selected_provider(request_options: {}, **params) ⇒ Auth0::Types::GetGuardianFactorsProviderPhoneResponseContent
Retrieve details of the multi-factor authentication phone provider configured for your tenant.
-
#get_templates(request_options: {}, **params) ⇒ Auth0::Types::GetGuardianFactorPhoneTemplatesResponseContent
Retrieve details of the multi-factor authentication enrollment and verification templates for phone-type factors available in your tenant.
-
#get_twilio_provider(request_options: {}, **params) ⇒ Auth0::Types::GetGuardianFactorsProviderPhoneTwilioResponseContent
Retrieve configuration details for a Twilio phone provider that has been set up in your tenant.
- #initialize(client:) ⇒ void constructor
-
#set_message_types(request_options: {}, **params) ⇒ Auth0::Types::SetGuardianFactorPhoneMessageTypesResponseContent
Replace the list of <a href=“auth0.com/docs/secure/multi-factor-authentication/multi-factor-authentication-factors/configure-sms-voice-notifications-mfa”>phone-type MFA factors</a> (i.e., sms and voice) that are enabled for your tenant.
- #set_provider(request_options: {}, **params) ⇒ Auth0::Types::SetGuardianFactorsProviderPhoneResponseContent
-
#set_templates(request_options: {}, **params) ⇒ Auth0::Types::SetGuardianFactorPhoneTemplatesResponseContent
Customize the messages sent to complete phone enrollment and verification (subscription required).
-
#set_twilio_provider(request_options: {}, **params) ⇒ Auth0::Types::SetGuardianFactorsProviderPhoneTwilioResponseContent
Update the configuration of a Twilio phone provider that has been set up in your tenant.
Constructor Details
#initialize(client:) ⇒ void
11 12 13 |
# File 'lib/auth0/guardian/factors/phone/client.rb', line 11 def initialize(client:) @client = client end |
Instance Method Details
#get_message_types(request_options: {}, **params) ⇒ Auth0::Types::GetGuardianFactorPhoneMessageTypesResponseContent
Retrieve list of <a href=“auth0.com/docs/secure/multi-factor-authentication/multi-factor-authentication-factors/configure-sms-voice-notifications-mfa”>phone-type MFA factors</a> (i.e., sms and voice) that are enabled for your tenant.
28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 |
# File 'lib/auth0/guardian/factors/phone/client.rb', line 28 def (request_options: {}, **params) Auth0::Internal::Types::Utils.normalize_keys(params) request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "GET", path: "guardian/factors/phone/message-types", request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Auth0::Types::GetGuardianFactorPhoneMessageTypesResponseContent.load(response.body) else error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#get_selected_provider(request_options: {}, **params) ⇒ Auth0::Types::GetGuardianFactorsProviderPhoneResponseContent
Retrieve details of the multi-factor authentication phone provider configured for your tenant.
170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 |
# File 'lib/auth0/guardian/factors/phone/client.rb', line 170 def get_selected_provider(request_options: {}, **params) Auth0::Internal::Types::Utils.normalize_keys(params) request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "GET", path: "guardian/factors/phone/selected-provider", request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Auth0::Types::GetGuardianFactorsProviderPhoneResponseContent.load(response.body) else error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#get_templates(request_options: {}, **params) ⇒ Auth0::Types::GetGuardianFactorPhoneTemplatesResponseContent
Retrieve details of the multi-factor authentication enrollment and verification templates for phone-type factors available in your tenant.
236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 |
# File 'lib/auth0/guardian/factors/phone/client.rb', line 236 def get_templates(request_options: {}, **params) Auth0::Internal::Types::Utils.normalize_keys(params) request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "GET", path: "guardian/factors/phone/templates", request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Auth0::Types::GetGuardianFactorPhoneTemplatesResponseContent.load(response.body) else error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#get_twilio_provider(request_options: {}, **params) ⇒ Auth0::Types::GetGuardianFactorsProviderPhoneTwilioResponseContent
Retrieve configuration details for a Twilio phone provider that has been set up in your tenant. To learn more, review <a href=“auth0.com/docs/secure/multi-factor-authentication/multi-factor-authentication-factors/configure-sms-voice-notifications-mfa”>Configure SMS and Voice Notifications for MFA</a>.
100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 |
# File 'lib/auth0/guardian/factors/phone/client.rb', line 100 def get_twilio_provider(request_options: {}, **params) Auth0::Internal::Types::Utils.normalize_keys(params) request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "GET", path: "guardian/factors/phone/providers/twilio", request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Auth0::Types::GetGuardianFactorsProviderPhoneTwilioResponseContent.load(response.body) else error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#set_message_types(request_options: {}, **params) ⇒ Auth0::Types::SetGuardianFactorPhoneMessageTypesResponseContent
Replace the list of <a href=“auth0.com/docs/secure/multi-factor-authentication/multi-factor-authentication-factors/configure-sms-voice-notifications-mfa”>phone-type MFA factors</a> (i.e., sms and voice) that are enabled for your tenant.
63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 |
# File 'lib/auth0/guardian/factors/phone/client.rb', line 63 def (request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "PUT", path: "guardian/factors/phone/message-types", body: Auth0::Guardian::Factors::Phone::Types::SetGuardianFactorPhoneMessageTypesRequestContent.new(params).to_h, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Auth0::Types::SetGuardianFactorPhoneMessageTypesResponseContent.load(response.body) else error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#set_provider(request_options: {}, **params) ⇒ Auth0::Types::SetGuardianFactorsProviderPhoneResponseContent
201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 |
# File 'lib/auth0/guardian/factors/phone/client.rb', line 201 def set_provider(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "PUT", path: "guardian/factors/phone/selected-provider", body: Auth0::Guardian::Factors::Phone::Types::SetGuardianFactorsProviderPhoneRequestContent.new(params).to_h, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Auth0::Types::SetGuardianFactorsProviderPhoneResponseContent.load(response.body) else error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#set_templates(request_options: {}, **params) ⇒ Auth0::Types::SetGuardianFactorPhoneTemplatesResponseContent
Customize the messages sent to complete phone enrollment and verification (subscription required).
269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 |
# File 'lib/auth0/guardian/factors/phone/client.rb', line 269 def set_templates(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "PUT", path: "guardian/factors/phone/templates", body: Auth0::Guardian::Factors::Phone::Types::SetGuardianFactorPhoneTemplatesRequestContent.new(params).to_h, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Auth0::Types::SetGuardianFactorPhoneTemplatesResponseContent.load(response.body) else error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#set_twilio_provider(request_options: {}, **params) ⇒ Auth0::Types::SetGuardianFactorsProviderPhoneTwilioResponseContent
Update the configuration of a Twilio phone provider that has been set up in your tenant. To learn more, review <a href=“auth0.com/docs/secure/multi-factor-authentication/multi-factor-authentication-factors/configure-sms-voice-notifications-mfa”>Configure SMS and Voice Notifications for MFA</a>.
136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 |
# File 'lib/auth0/guardian/factors/phone/client.rb', line 136 def set_twilio_provider(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "PUT", path: "guardian/factors/phone/providers/twilio", body: Auth0::Guardian::Factors::Phone::Types::SetGuardianFactorsProviderPhoneTwilioRequestContent.new(params).to_h, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Auth0::Types::SetGuardianFactorsProviderPhoneTwilioResponseContent.load(response.body) else error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |