Class: Auth0::Hooks::Client
- Inherits:
-
Object
- Object
- Auth0::Hooks::Client
- Defined in:
- lib/auth0/hooks/client.rb
Instance Method Summary collapse
-
#create(request_options: {}, **params) ⇒ Auth0::Types::CreateHookResponseContent
Create a new hook.
-
#delete(request_options: {}, **params) ⇒ untyped
Delete a hook.
-
#get(request_options: {}, **params) ⇒ Auth0::Types::GetHookResponseContent
Retrieve <a href=“auth0.com/docs/hooks”>a hook</a> by its ID.
- #initialize(client:) ⇒ void constructor
-
#list(request_options: {}, **params) ⇒ Auth0::Types::ListHooksOffsetPaginatedResponseContent
Retrieve all <a href=“auth0.com/docs/hooks”>hooks</a>.
- #secrets ⇒ Auth0::Secrets::Client
-
#update(request_options: {}, **params) ⇒ Auth0::Types::UpdateHookResponseContent
Update an existing hook.
Constructor Details
#initialize(client:) ⇒ void
9 10 11 |
# File 'lib/auth0/hooks/client.rb', line 9 def initialize(client:) @client = client end |
Instance Method Details
#create(request_options: {}, **params) ⇒ Auth0::Types::CreateHookResponseContent
Create a new hook.
83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'lib/auth0/hooks/client.rb', line 83 def create(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "POST", path: "hooks", body: Auth0::Hooks::Types::CreateHookRequestContent.new(params).to_h, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Auth0::Types::CreateHookResponseContent.load(response.body) else error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#delete(request_options: {}, **params) ⇒ untyped
Delete a hook.
160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 |
# File 'lib/auth0/hooks/client.rb', line 160 def delete(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "DELETE", path: "hooks/#{URI.encode_uri_component(params[:id].to_s)}", request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i return if code.between?(200, 299) error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end |
#get(request_options: {}, **params) ⇒ Auth0::Types::GetHookResponseContent
Retrieve <a href=“auth0.com/docs/hooks”>a hook</a> by its ID. Accepts a list of fields to include in the result.
120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 |
# File 'lib/auth0/hooks/client.rb', line 120 def get(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) query_param_names = %i[fields] query_params = {} query_params["fields"] = params[:fields] if params.key?(:fields) params = params.except(*query_param_names) request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "GET", path: "hooks/#{URI.encode_uri_component(params[:id].to_s)}", query: query_params, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Auth0::Types::GetHookResponseContent.load(response.body) else error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#list(request_options: {}, **params) ⇒ Auth0::Types::ListHooksOffsetPaginatedResponseContent
Retrieve all <a href=“auth0.com/docs/hooks”>hooks</a>. Accepts a list of fields to include or exclude in the result.
31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/auth0/hooks/client.rb', line 31 def list(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) query_param_names = %i[page per_page include_totals enabled fields trigger_id] query_params = {} query_params["page"] = params.fetch(:page, 0) query_params["per_page"] = params.fetch(:per_page, 50) query_params["include_totals"] = params.fetch(:include_totals, true) query_params["enabled"] = params[:enabled] if params.key?(:enabled) query_params["fields"] = params[:fields] if params.key?(:fields) query_params["triggerId"] = params[:trigger_id] if params.key?(:trigger_id) params.except(*query_param_names) Auth0::Internal::OffsetItemIterator.new( initial_page: query_params["page"], item_field: :hooks, has_next_field: nil, step: true ) do |next_page| query_params["page"] = next_page request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "GET", path: "hooks", query: query_params, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Auth0::Types::ListHooksOffsetPaginatedResponseContent.load(response.body) else error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end end |
#secrets ⇒ Auth0::Secrets::Client
220 221 222 |
# File 'lib/auth0/hooks/client.rb', line 220 def secrets @secrets ||= Auth0::Hooks::Secrets::Client.new(client: @client) end |
#update(request_options: {}, **params) ⇒ Auth0::Types::UpdateHookResponseContent
Update an existing hook.
192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 |
# File 'lib/auth0/hooks/client.rb', line 192 def update(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) request_data = Auth0::Hooks::Types::UpdateHookRequestContent.new(params).to_h non_body_param_names = ["id"] body = request_data.except(*non_body_param_names) request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "PATCH", path: "hooks/#{URI.encode_uri_component(params[:id].to_s)}", body: body, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Auth0::Types::UpdateHookResponseContent.load(response.body) else error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |