Class: Auth0::Hooks::Secrets::Client
- Inherits:
-
Object
- Object
- Auth0::Hooks::Secrets::Client
- Defined in:
- lib/auth0/hooks/secrets/client.rb
Instance Method Summary collapse
-
#create(request_options: {}, **params) ⇒ untyped
Add one or more secrets to an existing hook.
-
#delete(request_options: {}, **params) ⇒ untyped
Delete one or more existing secrets for a given hook.
-
#get(request_options: {}, **params) ⇒ Hash[String, String]
Retrieve a hook’s secrets by the ID of the hook.
- #initialize(client:) ⇒ void constructor
-
#update(request_options: {}, **params) ⇒ untyped
Update one or more existing secrets for an existing hook.
Constructor Details
#initialize(client:) ⇒ void
10 11 12 |
# File 'lib/auth0/hooks/secrets/client.rb', line 10 def initialize(client:) @client = client end |
Instance Method Details
#create(request_options: {}, **params) ⇒ untyped
Add one or more secrets to an existing hook. Accepts an object of key-value pairs, where the key is the name of the secret. A hook can have a maximum of 20 secrets.
61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/auth0/hooks/secrets/client.rb', line 61 def create(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "POST", path: "hooks/#{URI.encode_uri_component(params[:id].to_s)}/secrets", body: params, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i return if code.between?(200, 299) error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end |
#delete(request_options: {}, **params) ⇒ untyped
Delete one or more existing secrets for a given hook. Accepts an array of secret names to delete.
94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 |
# File 'lib/auth0/hooks/secrets/client.rb', line 94 def delete(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "DELETE", path: "hooks/#{URI.encode_uri_component(params[:id].to_s)}/secrets", body: params, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i return if code.between?(200, 299) error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end |
#get(request_options: {}, **params) ⇒ Hash[String, String]
Retrieve a hook’s secrets by the ID of the hook.
26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 |
# File 'lib/auth0/hooks/secrets/client.rb', line 26 def get(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "GET", path: "hooks/#{URI.encode_uri_component(params[:id].to_s)}/secrets", request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Auth0::Types::GetHookSecretResponseContent.load(response.body) else error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#update(request_options: {}, **params) ⇒ untyped
Update one or more existing secrets for an existing hook. Accepts an object of key-value pairs, where the key is the name of the existing secret.
128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 |
# File 'lib/auth0/hooks/secrets/client.rb', line 128 def update(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "PATCH", path: "hooks/#{URI.encode_uri_component(params[:id].to_s)}/secrets", body: params, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i return if code.between?(200, 299) error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end |