Class: Auth0::Jobs::VerificationEmail::Client
- Inherits:
-
Object
- Object
- Auth0::Jobs::VerificationEmail::Client
- Defined in:
- lib/auth0/jobs/verification_email/client.rb
Instance Method Summary collapse
-
#create(request_options: {}, **params) ⇒ Auth0::Types::CreateVerificationEmailResponseContent
Send an email to the specified user that asks them to click a link to <a href=“auth0.com/docs/email/custom#verification-email”>verify their email address</a>.
- #initialize(client:) ⇒ void constructor
Constructor Details
#initialize(client:) ⇒ void
10 11 12 |
# File 'lib/auth0/jobs/verification_email/client.rb', line 10 def initialize(client:) @client = client end |
Instance Method Details
#create(request_options: {}, **params) ⇒ Auth0::Types::CreateVerificationEmailResponseContent
Send an email to the specified user that asks them to click a link to <a href=“auth0.com/docs/email/custom#verification-email”>verify their email address</a>.
Note: You must have the ‘Status` toggle enabled for the verification email template for the email to be sent.
28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 |
# File 'lib/auth0/jobs/verification_email/client.rb', line 28 def create(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "POST", path: "jobs/verification-email", body: Auth0::Jobs::VerificationEmail::Types::CreateVerificationEmailRequestContent.new(params).to_h, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Auth0::Types::CreateVerificationEmailResponseContent.load(response.body) else error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |