Class: Auth0::OrganizationTemplates::Client
- Inherits:
-
Object
- Object
- Auth0::OrganizationTemplates::Client
- Defined in:
- lib/auth0/organization_templates/client.rb
Instance Method Summary collapse
-
#create(request_options: {}, **params) ⇒ Auth0::Types::OrganizationTemplate
Create an Organization Template.
-
#get(request_options: {}, **params) ⇒ Auth0::Types::OrganizationTemplate
Retrieve details about a single Organization Template specified by ID.
- #initialize(client:) ⇒ void constructor
-
#list(request_options: {}, **params) ⇒ Auth0::Types::ListOrganizationTemplatesPaginatedResponseContent
Retrieve a list of Organization Templates.
-
#list_organizations(request_options: {}, **params) ⇒ Auth0::Types::ListTemplateOrganizationsPaginatedResponseContent
Retrieve a list of organizations assigned to an Organization Template.
-
#update(request_options: {}, **params) ⇒ Auth0::Types::OrganizationTemplate
Update the details of a specific Organization Template.
Constructor Details
#initialize(client:) ⇒ void
9 10 11 |
# File 'lib/auth0/organization_templates/client.rb', line 9 def initialize(client:) @client = client end |
Instance Method Details
#create(request_options: {}, **params) ⇒ Auth0::Types::OrganizationTemplate
Create an Organization Template.
73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 |
# File 'lib/auth0/organization_templates/client.rb', line 73 def create(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "POST", path: "organization-templates", body: Auth0::OrganizationTemplates::Types::CreateOrganizationTemplateRequestContent.new(params).to_h, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Auth0::Types::OrganizationTemplate.load(response.body) else error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#get(request_options: {}, **params) ⇒ Auth0::Types::OrganizationTemplate
Retrieve details about a single Organization Template specified by ID.
108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 |
# File 'lib/auth0/organization_templates/client.rb', line 108 def get(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "GET", path: "organization-templates/#{URI.encode_uri_component(params[:id].to_s)}", request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Auth0::Types::OrganizationTemplate.load(response.body) else error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#list(request_options: {}, **params) ⇒ Auth0::Types::ListOrganizationTemplatesPaginatedResponseContent
Retrieve a list of Organization Templates. This endpoint supports Checkpoint pagination. Results are returned in
a stable order, sorted by their identifier (id) in ascending order.
27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 |
# File 'lib/auth0/organization_templates/client.rb', line 27 def list(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) query_params = {} query_params["from"] = params[:from] if params.key?(:from) query_params["take"] = params.fetch(:take, 5) Auth0::Internal::CursorItemIterator.new( cursor_field: :next_, item_field: :organization_templates, initial_cursor: query_params["from"] ) do |next_cursor| query_params["from"] = next_cursor request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "GET", path: "organization-templates", query: query_params, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) parsed_response = Auth0::Types::ListOrganizationTemplatesPaginatedResponseContent.load(response.body) [parsed_response, response] else error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end end |
#list_organizations(request_options: {}, **params) ⇒ Auth0::Types::ListTemplateOrganizationsPaginatedResponseContent
Retrieve a list of organizations assigned to an Organization Template. This endpoint supports Checkpoint
pagination. Results are returned in a stable order, sorted by their identifier (id) in ascending order.
184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 |
# File 'lib/auth0/organization_templates/client.rb', line 184 def list_organizations(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) query_params = {} query_params["from"] = params[:from] if params.key?(:from) query_params["take"] = params.fetch(:take, 5) Auth0::Internal::CursorItemIterator.new( cursor_field: :next_, item_field: :organizations, initial_cursor: query_params["from"] ) do |next_cursor| query_params["from"] = next_cursor request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "GET", path: "organization-templates/#{URI.encode_uri_component(params[:id].to_s)}/organizations", query: query_params, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) parsed_response = Auth0::Types::ListTemplateOrganizationsPaginatedResponseContent.load(response.body) [parsed_response, response] else error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end end |
#update(request_options: {}, **params) ⇒ Auth0::Types::OrganizationTemplate
Update the details of a specific Organization Template.
142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 |
# File 'lib/auth0/organization_templates/client.rb', line 142 def update(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) request_data = Auth0::OrganizationTemplates::Types::UpdateOrganizationTemplateRequestContent.new(params).to_h non_body_param_names = %w[id] body = request_data.except(*non_body_param_names) request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "PATCH", path: "organization-templates/#{URI.encode_uri_component(params[:id].to_s)}", body: body, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Auth0::Types::OrganizationTemplate.load(response.body) else error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |