Class: Auth0::Organizations::OrganizationTemplate::Client
- Inherits:
-
Object
- Object
- Auth0::Organizations::OrganizationTemplate::Client
- Defined in:
- lib/auth0/organizations/organization_template/client.rb
Instance Method Summary collapse
-
#assign_organization_template(request_options: {}, **params) ⇒ untyped
Assign an Organization Template to an organization.
-
#get(request_options: {}, **params) ⇒ Auth0::Types::OrganizationTemplate
Retrieve the organization template assigned to a specific organization.
- #initialize(client:) ⇒ void constructor
-
#unassign_organization_template(request_options: {}, **params) ⇒ untyped
Remove an Organization Template assignment from an organization.
Constructor Details
#initialize(client:) ⇒ void
10 11 12 |
# File 'lib/auth0/organizations/organization_template/client.rb', line 10 def initialize(client:) @client = client end |
Instance Method Details
#assign_organization_template(request_options: {}, **params) ⇒ untyped
Assign an Organization Template to an organization.
71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/auth0/organizations/organization_template/client.rb', line 71 def assign_organization_template(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "PUT", path: "organizations/#{URI.encode_uri_component(params[:id].to_s)}/organization-templates/#{URI.encode_uri_component(params[:template_id].to_s)}", request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i return if code.between?(200, 299) error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end |
#get(request_options: {}, **params) ⇒ Auth0::Types::OrganizationTemplate
Retrieve the organization template assigned to a specific organization. Returns the template object if one is explicitly assigned, or a 404 if no template is assigned.
30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 |
# File 'lib/auth0/organizations/organization_template/client.rb', line 30 def get(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "GET", path: "organizations/#{URI.encode_uri_component(params[:id].to_s)}/organization-templates", request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) (response.body.to_s.empty? ? nil : Auth0::Types::OrganizationTemplate.load(response.body)) else error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#unassign_organization_template(request_options: {}, **params) ⇒ untyped
Remove an Organization Template assignment from an organization.
110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 |
# File 'lib/auth0/organizations/organization_template/client.rb', line 110 def unassign_organization_template(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "DELETE", path: "organizations/#{URI.encode_uri_component(params[:id].to_s)}/organization-templates/#{URI.encode_uri_component(params[:template_id].to_s)}", request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i return if code.between?(200, 299) error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end |