Class: Auth0::Prompts::Rendering::Client
- Inherits:
-
Object
- Object
- Auth0::Prompts::Rendering::Client
- Defined in:
- lib/auth0/prompts/rendering/client.rb
Instance Method Summary collapse
-
#bulk_update(request_options: {}, **params) ⇒ Auth0::Types::BulkUpdateAculResponseContent
Learn more about configuring render settings for advanced customization.
-
#get(request_options: {}, **params) ⇒ Auth0::Types::GetAculResponseContent
Get render settings for a screen.
- #initialize(client:) ⇒ void constructor
-
#list(request_options: {}, **params) ⇒ Auth0::Types::ListAculsOffsetPaginatedResponseContent
Get render setting configurations for all screens.
-
#update(request_options: {}, **params) ⇒ Auth0::Types::UpdateAculResponseContent
Learn more about configuring render settings for advanced customization.
Constructor Details
#initialize(client:) ⇒ void
10 11 12 |
# File 'lib/auth0/prompts/rendering/client.rb', line 10 def initialize(client:) @client = client end |
Instance Method Details
#bulk_update(request_options: {}, **params) ⇒ Auth0::Types::BulkUpdateAculResponseContent
Learn more about configuring render settings for advanced customization.
106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 |
# File 'lib/auth0/prompts/rendering/client.rb', line 106 def bulk_update(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "PATCH", path: "prompts/rendering", body: Auth0::Prompts::Rendering::Types::BulkUpdateAculRequestContent.new(params).to_h, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) (response.body.to_s.empty? ? nil : Auth0::Types::BulkUpdateAculResponseContent.load(response.body)) else error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#get(request_options: {}, **params) ⇒ Auth0::Types::GetAculResponseContent
Get render settings for a screen.
148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 |
# File 'lib/auth0/prompts/rendering/client.rb', line 148 def get(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "GET", path: "prompts/#{URI.encode_uri_component(params[:prompt].to_s)}/screen/#{URI.encode_uri_component(params[:screen].to_s)}/rendering", request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) (response.body.to_s.empty? ? nil : Auth0::Types::GetAculResponseContent.load(response.body)) else error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#list(request_options: {}, **params) ⇒ Auth0::Types::ListAculsOffsetPaginatedResponseContent
Get render setting configurations for all screens.
45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 |
# File 'lib/auth0/prompts/rendering/client.rb', line 45 def list(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) query_params = {} query_params["fields"] = params[:fields] if params.key?(:fields) query_params["include_fields"] = params[:include_fields] if params.key?(:include_fields) query_params["page"] = params.fetch(:page, 0) query_params["per_page"] = params.fetch(:per_page, 50) query_params["include_totals"] = params.fetch(:include_totals, true) query_params["prompt"] = params[:prompt] if params.key?(:prompt) query_params["screen"] = params[:screen] if params.key?(:screen) query_params["rendering_mode"] = params[:rendering_mode] if params.key?(:rendering_mode) Auth0::Internal::OffsetItemIterator.new( initial_page: query_params["page"], item_field: :configs, has_next_field: nil, step: false ) do |next_page| query_params["page"] = next_page request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "GET", path: "prompts/rendering", query: query_params, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) parsed_response = (response.body.to_s.empty? ? nil : Auth0::Types::ListAculsOffsetPaginatedResponseContent.load(response.body)) [parsed_response, response] else error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end end |
#update(request_options: {}, **params) ⇒ Auth0::Types::UpdateAculResponseContent
Learn more about configuring render settings for advanced customization.
191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 |
# File 'lib/auth0/prompts/rendering/client.rb', line 191 def update(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) request_data = Auth0::Prompts::Rendering::Types::UpdateAculRequestContent.new(params).to_h non_body_param_names = %w[prompt screen] body = request_data.except(*non_body_param_names) request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "PATCH", path: "prompts/#{URI.encode_uri_component(params[:prompt].to_s)}/screen/#{URI.encode_uri_component(params[:screen].to_s)}/rendering", body: body, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) (response.body.to_s.empty? ? nil : Auth0::Types::UpdateAculResponseContent.load(response.body)) else error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |