Class: Auth0::RefreshTokens::Client
- Inherits:
-
Object
- Object
- Auth0::RefreshTokens::Client
- Defined in:
- lib/auth0/refresh_tokens/client.rb
Instance Method Summary collapse
-
#delete(request_options: {}, **params) ⇒ untyped
Delete a refresh token by its ID.
-
#get(request_options: {}, **params) ⇒ Auth0::Types::GetRefreshTokenResponseContent
Retrieve refresh token information.
- #initialize(client:) ⇒ void constructor
-
#list(request_options: {}, **params) ⇒ Auth0::Types::GetRefreshTokensPaginatedResponseContent
Retrieve a paginated list of refresh tokens for a specific user, with optional filtering by client ID.
-
#update(request_options: {}, **params) ⇒ Auth0::Types::UpdateRefreshTokenResponseContent
Update a refresh token by its ID.
Constructor Details
#initialize(client:) ⇒ void
9 10 11 |
# File 'lib/auth0/refresh_tokens/client.rb', line 9 def initialize(client:) @client = client end |
Instance Method Details
#delete(request_options: {}, **params) ⇒ untyped
Delete a refresh token by its ID.
117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 |
# File 'lib/auth0/refresh_tokens/client.rb', line 117 def delete(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "DELETE", path: "refresh-tokens/#{URI.encode_uri_component(params[:id].to_s)}", request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i return if code.between?(200, 299) error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end |
#get(request_options: {}, **params) ⇒ Auth0::Types::GetRefreshTokenResponseContent
Retrieve refresh token information.
83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/auth0/refresh_tokens/client.rb', line 83 def get(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "GET", path: "refresh-tokens/#{URI.encode_uri_component(params[:id].to_s)}", request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Auth0::Types::GetRefreshTokenResponseContent.load(response.body) else error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#list(request_options: {}, **params) ⇒ Auth0::Types::GetRefreshTokensPaginatedResponseContent
Retrieve a paginated list of refresh tokens for a specific user, with optional filtering by client ID. Results are sorted by credential_id ascending.
31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 |
# File 'lib/auth0/refresh_tokens/client.rb', line 31 def list(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) query_param_names = %i[user_id client_id from take fields include_fields] query_params = {} query_params["user_id"] = params[:user_id] if params.key?(:user_id) query_params["client_id"] = params[:client_id] if params.key?(:client_id) query_params["from"] = params[:from] if params.key?(:from) query_params["take"] = params.fetch(:take, 50) query_params["fields"] = params[:fields] if params.key?(:fields) query_params["include_fields"] = params[:include_fields] if params.key?(:include_fields) params.except(*query_param_names) Auth0::Internal::CursorItemIterator.new( cursor_field: :next_, item_field: :refresh_tokens, initial_cursor: query_params["from"] ) do |next_cursor| query_params["from"] = next_cursor request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "GET", path: "refresh-tokens", query: query_params, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Auth0::Types::GetRefreshTokensPaginatedResponseContent.load(response.body) else error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end end |
#update(request_options: {}, **params) ⇒ Auth0::Types::UpdateRefreshTokenResponseContent
Update a refresh token by its ID.
149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 |
# File 'lib/auth0/refresh_tokens/client.rb', line 149 def update(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) request_data = Auth0::RefreshTokens::Types::UpdateRefreshTokenRequestContent.new(params).to_h non_body_param_names = ["id"] body = request_data.except(*non_body_param_names) request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "PATCH", path: "refresh-tokens/#{URI.encode_uri_component(params[:id].to_s)}", body: body, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Auth0::Types::UpdateRefreshTokenResponseContent.load(response.body) else error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |