Class: Auth0::SelfServiceProfiles::SSOTicket::Client
- Inherits:
-
Object
- Object
- Auth0::SelfServiceProfiles::SSOTicket::Client
- Defined in:
- lib/auth0/self_service_profiles/sso_ticket/client.rb
Instance Method Summary collapse
-
#create(request_options: {}, **params) ⇒ Auth0::Types::CreateSelfServiceProfileSSOTicketResponseContent
Creates an SSO access ticket to initiate the Self Service SSO Flow using a self-service profile.
- #initialize(client:) ⇒ void constructor
-
#revoke(request_options: {}, **params) ⇒ untyped
Revokes an SSO access ticket and invalidates associated sessions.
Constructor Details
#initialize(client:) ⇒ void
10 11 12 |
# File 'lib/auth0/self_service_profiles/sso_ticket/client.rb', line 10 def initialize(client:) @client = client end |
Instance Method Details
#create(request_options: {}, **params) ⇒ Auth0::Types::CreateSelfServiceProfileSSOTicketResponseContent
Creates an SSO access ticket to initiate the Self Service SSO Flow using a self-service profile.
26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 |
# File 'lib/auth0/self_service_profiles/sso_ticket/client.rb', line 26 def create(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) request_data = Auth0::SelfServiceProfiles::SSOTicket::Types::CreateSelfServiceProfileSSOTicketRequestContent.new(params).to_h non_body_param_names = ["id"] body = request_data.except(*non_body_param_names) request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "POST", path: "self-service-profiles/#{URI.encode_uri_component(params[:id].to_s)}/sso-ticket", body: body, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Auth0::Types::CreateSelfServiceProfileSSOTicketResponseContent.load(response.body) else error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#revoke(request_options: {}, **params) ⇒ untyped
Revokes an SSO access ticket and invalidates associated sessions. The ticket will no longer be accepted to initiate a Self-Service SSO session. If any users have already started a session through this ticket, their session will be terminated. Clients should expect a ‘202 Accepted` response upon successful processing, indicating that the request has been acknowledged and that the revocation is underway but may not be fully completed at the time of response. If the specified ticket does not exist, a `202 Accepted` response is also returned, signaling that no further action is required. Clients should treat these `202` responses as an acknowledgment that the request has been accepted and is in progress, even if the ticket was not found.
73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 |
# File 'lib/auth0/self_service_profiles/sso_ticket/client.rb', line 73 def revoke(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "POST", path: "self-service-profiles/#{URI.encode_uri_component(params[:profile_id].to_s)}/sso-ticket/#{URI.encode_uri_component(params[:id].to_s)}/revoke", request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i return if code.between?(200, 299) error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end |