Class: Auth0::Stats::Client
- Inherits:
-
Object
- Object
- Auth0::Stats::Client
- Defined in:
- lib/auth0/stats/client.rb
Instance Method Summary collapse
-
#get_active_users_count(request_options: {}, **params) ⇒ Integer
Retrieve the number of active users that logged in during the last 30 days.
-
#get_daily(request_options: {}, **params) ⇒ Array[Auth0::Types::DailyStats]
Retrieve the number of logins, signups and breached-password detections (subscription required) that occurred each day within a specified date range.
- #initialize(client:) ⇒ void constructor
Constructor Details
#initialize(client:) ⇒ void
9 10 11 |
# File 'lib/auth0/stats/client.rb', line 9 def initialize(client:) @client = client end |
Instance Method Details
#get_active_users_count(request_options: {}, **params) ⇒ Integer
Retrieve the number of active users that logged in during the last 30 days.
24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 |
# File 'lib/auth0/stats/client.rb', line 24 def get_active_users_count(request_options: {}, **params) Auth0::Internal::Types::Utils.normalize_keys(params) request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "GET", path: "stats/active-users", request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Auth0::Types::GetActiveUsersCountStatsResponseContent.load(response.body) else error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#get_daily(request_options: {}, **params) ⇒ Array[Auth0::Types::DailyStats]
Retrieve the number of logins, signups and breached-password detections (subscription required) that occurred each day within a specified date range.
60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 |
# File 'lib/auth0/stats/client.rb', line 60 def get_daily(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) query_param_names = %i[from to] query_params = {} query_params["from"] = params[:from] if params.key?(:from) query_params["to"] = params[:to] if params.key?(:to) params.except(*query_param_names) request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "GET", path: "stats/daily", query: query_params, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i return if code.between?(200, 299) error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end |