Class: Auth0::Types::DefaultTokenQuota
- Inherits:
-
Internal::Types::Model
- Object
- Internal::Types::Model
- Auth0::Types::DefaultTokenQuota
- Defined in:
- lib/auth0/types/default_token_quota.rb
Overview
Token Quota configuration, to configure quotas for token issuance for clients and organizations. Applied to all clients and organizations unless overridden in individual client or organization settings.
Method Summary
Methods inherited from Internal::Types::Model
#==, ===, add_extra_field_definition, coerce, extra_fields, field, fields, #initialize, #inspect, literal, load, #to_h
Methods included from Internal::Types::Type
Methods included from Internal::JSON::Serializable
Constructor Details
This class inherits a constructor from Auth0::Internal::Types::Model