Class: Auth0::UserAttributeProfiles::Client
- Inherits:
-
Object
- Object
- Auth0::UserAttributeProfiles::Client
- Defined in:
- lib/auth0/user_attribute_profiles/client.rb
Instance Method Summary collapse
-
#create(request_options: {}, **params) ⇒ Auth0::Types::CreateUserAttributeProfileResponseContent
Create a User Attribute Profile.
-
#delete(request_options: {}, **params) ⇒ untyped
Delete a single User Attribute Profile specified by ID.
-
#get(request_options: {}, **params) ⇒ Auth0::Types::GetUserAttributeProfileResponseContent
Retrieve details about a single User Attribute Profile specified by ID.
-
#get_template(request_options: {}, **params) ⇒ Auth0::Types::GetUserAttributeProfileTemplateResponseContent
Retrieve a User Attribute Profile Template.
- #initialize(client:) ⇒ void constructor
-
#list(request_options: {}, **params) ⇒ Auth0::Types::ListUserAttributeProfilesPaginatedResponseContent
Retrieve a list of User Attribute Profiles.
-
#list_templates(request_options: {}, **_params) ⇒ Auth0::Types::ListUserAttributeProfileTemplateResponseContent
Retrieve a list of User Attribute Profile Templates.
-
#update(request_options: {}, **params) ⇒ Auth0::Types::UpdateUserAttributeProfileResponseContent
Update the details of a specific User attribute profile, such as name, user_id and user_attributes.
Constructor Details
#initialize(client:) ⇒ void
9 10 11 |
# File 'lib/auth0/user_attribute_profiles/client.rb', line 9 def initialize(client:) @client = client end |
Instance Method Details
#create(request_options: {}, **params) ⇒ Auth0::Types::CreateUserAttributeProfileResponseContent
Create a User Attribute Profile.
91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 |
# File 'lib/auth0/user_attribute_profiles/client.rb', line 91 def create(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "POST", path: "user-attribute-profiles", body: Auth0::UserAttributeProfiles::Types::CreateUserAttributeProfileRequestContent.new(params).to_h, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) (response.body.to_s.empty? ? nil : Auth0::Types::CreateUserAttributeProfileResponseContent.load(response.body)) else error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#delete(request_options: {}, **params) ⇒ untyped
Delete a single User Attribute Profile specified by ID.
238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 |
# File 'lib/auth0/user_attribute_profiles/client.rb', line 238 def delete(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "DELETE", path: "user-attribute-profiles/#{URI.encode_uri_component(params[:id].to_s)}", request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i return if code.between?(200, 299) error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end |
#get(request_options: {}, **params) ⇒ Auth0::Types::GetUserAttributeProfileResponseContent
Retrieve details about a single User Attribute Profile specified by ID.
201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 |
# File 'lib/auth0/user_attribute_profiles/client.rb', line 201 def get(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "GET", path: "user-attribute-profiles/#{URI.encode_uri_component(params[:id].to_s)}", request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) (response.body.to_s.empty? ? nil : Auth0::Types::GetUserAttributeProfileResponseContent.load(response.body)) else error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#get_template(request_options: {}, **params) ⇒ Auth0::Types::GetUserAttributeProfileTemplateResponseContent
Retrieve a User Attribute Profile Template.
164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 |
# File 'lib/auth0/user_attribute_profiles/client.rb', line 164 def get_template(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "GET", path: "user-attribute-profiles/templates/#{URI.encode_uri_component(params[:id].to_s)}", request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) (response.body.to_s.empty? ? nil : Auth0::Types::GetUserAttributeProfileTemplateResponseContent.load(response.body)) else error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#list(request_options: {}, **params) ⇒ Auth0::Types::ListUserAttributeProfilesPaginatedResponseContent
Retrieve a list of User Attribute Profiles. This endpoint supports Checkpoint pagination.
32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 |
# File 'lib/auth0/user_attribute_profiles/client.rb', line 32 def list(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) query_params = {} query_params["from"] = params[:from] if params.key?(:from) query_params["take"] = params.fetch(:take, 50) Auth0::Internal::CursorItemIterator.new( cursor_field: :next_, item_field: :user_attribute_profiles, initial_cursor: query_params["from"] ) do |next_cursor| query_params["from"] = next_cursor request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "GET", path: "user-attribute-profiles", query: query_params, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) parsed_response = (response.body.to_s.empty? ? nil : Auth0::Types::ListUserAttributeProfilesPaginatedResponseContent.load(response.body)) [parsed_response, response] else error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end end |
#list_templates(request_options: {}, **_params) ⇒ Auth0::Types::ListUserAttributeProfileTemplateResponseContent
Retrieve a list of User Attribute Profile Templates.
128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 |
# File 'lib/auth0/user_attribute_profiles/client.rb', line 128 def list_templates(request_options: {}, **_params) request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "GET", path: "user-attribute-profiles/templates", request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) (response.body.to_s.empty? ? nil : Auth0::Types::ListUserAttributeProfileTemplateResponseContent.load(response.body)) else error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#update(request_options: {}, **params) ⇒ Auth0::Types::UpdateUserAttributeProfileResponseContent
Update the details of a specific User attribute profile, such as name, user_id and user_attributes.
273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 |
# File 'lib/auth0/user_attribute_profiles/client.rb', line 273 def update(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) request_data = Auth0::UserAttributeProfiles::Types::UpdateUserAttributeProfileRequestContent.new(params).to_h non_body_param_names = %w[id] body = request_data.except(*non_body_param_names) request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "PATCH", path: "user-attribute-profiles/#{URI.encode_uri_component(params[:id].to_s)}", body: body, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) (response.body.to_s.empty? ? nil : Auth0::Types::UpdateUserAttributeProfileResponseContent.load(response.body)) else error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |