Class: Auth0::Users::AuthenticationMethods::Client
- Inherits:
-
Object
- Object
- Auth0::Users::AuthenticationMethods::Client
- Defined in:
- lib/auth0/users/authentication_methods/client.rb
Instance Method Summary collapse
-
#create(request_options: {}, **params) ⇒ Auth0::Types::CreateUserAuthenticationMethodResponseContent
Create an authentication method.
-
#delete(request_options: {}, **params) ⇒ untyped
Remove the authentication method with the given ID from the specified user.
-
#delete_all(request_options: {}, **params) ⇒ untyped
Remove all authentication methods (i.e., enrolled MFA factors) from the specified user account.
- #get(request_options: {}, **params) ⇒ Auth0::Types::GetUserAuthenticationMethodResponseContent
- #initialize(client:) ⇒ void constructor
-
#list(request_options: {}, **params) ⇒ Auth0::Types::ListUserAuthenticationMethodsOffsetPaginatedResponseContent
Retrieve detailed list of authentication methods associated with a specified user.
-
#set(request_options: {}, **params) ⇒ Array[Auth0::Types::SetUserAuthenticationMethodResponseContent]
Replace the specified user authentication methods with supplied values.
-
#update(request_options: {}, **params) ⇒ Auth0::Types::UpdateUserAuthenticationMethodResponseContent
Modify the authentication method with the given ID from the specified user.
Constructor Details
#initialize(client:) ⇒ void
10 11 12 |
# File 'lib/auth0/users/authentication_methods/client.rb', line 10 def initialize(client:) @client = client end |
Instance Method Details
#create(request_options: {}, **params) ⇒ Auth0::Types::CreateUserAuthenticationMethodResponseContent
Create an authentication method. Authentication methods created via this endpoint will be auto confirmed and should already have verification completed.
93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 |
# File 'lib/auth0/users/authentication_methods/client.rb', line 93 def create(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) request_data = Auth0::Users::AuthenticationMethods::Types::CreateUserAuthenticationMethodRequestContent.new(params).to_h non_body_param_names = %w[id] body = request_data.except(*non_body_param_names) request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "POST", path: "users/#{URI.encode_uri_component(params[:id].to_s)}/authentication-methods", body: body, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) (response.body.to_s.empty? ? nil : Auth0::Types::CreateUserAuthenticationMethodResponseContent.load(response.body)) else error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#delete(request_options: {}, **params) ⇒ untyped
Remove the authentication method with the given ID from the specified user. For more information, review Manage Authentication Methods with Management API.
267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 |
# File 'lib/auth0/users/authentication_methods/client.rb', line 267 def delete(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "DELETE", path: "users/#{URI.encode_uri_component(params[:id].to_s)}/authentication-methods/#{URI.encode_uri_component(params[:authentication_method_id].to_s)}", request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i return if code.between?(200, 299) error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end |
#delete_all(request_options: {}, **params) ⇒ untyped
Remove all authentication methods (i.e., enrolled MFA factors) from the specified user account. This action cannot be undone.
187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 |
# File 'lib/auth0/users/authentication_methods/client.rb', line 187 def delete_all(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "DELETE", path: "users/#{URI.encode_uri_component(params[:id].to_s)}/authentication-methods", request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i return if code.between?(200, 299) error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end |
#get(request_options: {}, **params) ⇒ Auth0::Types::GetUserAuthenticationMethodResponseContent
224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 |
# File 'lib/auth0/users/authentication_methods/client.rb', line 224 def get(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "GET", path: "users/#{URI.encode_uri_component(params[:id].to_s)}/authentication-methods/#{URI.encode_uri_component(params[:authentication_method_id].to_s)}", request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) (response.body.to_s.empty? ? nil : Auth0::Types::GetUserAuthenticationMethodResponseContent.load(response.body)) else error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#list(request_options: {}, **params) ⇒ Auth0::Types::ListUserAuthenticationMethodsOffsetPaginatedResponseContent
Retrieve detailed list of authentication methods associated with a specified user.
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/auth0/users/authentication_methods/client.rb', line 37 def list(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) query_params = {} query_params["page"] = params.fetch(:page, 0) query_params["per_page"] = params.fetch(:per_page, 50) query_params["include_totals"] = params.fetch(:include_totals, true) Auth0::Internal::OffsetItemIterator.new( initial_page: query_params["page"], item_field: :authenticators, has_next_field: nil, step: false ) do |next_page| query_params["page"] = next_page request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "GET", path: "users/#{URI.encode_uri_component(params[:id].to_s)}/authentication-methods", query: query_params, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) parsed_response = (response.body.to_s.empty? ? nil : Auth0::Types::ListUserAuthenticationMethodsOffsetPaginatedResponseContent.load(response.body)) [parsed_response, response] else error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end end |
#set(request_options: {}, **params) ⇒ Array[Auth0::Types::SetUserAuthenticationMethodResponseContent]
Replace the specified user authentication methods with supplied values.
Note: Authentication methods supplied through this action do not iterate on existing methods. Instead, any methods passed will overwrite the user’s existing settings.
145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 |
# File 'lib/auth0/users/authentication_methods/client.rb', line 145 def set(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) path_param_names = %i[id] body_params = params.except(*path_param_names) request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "PUT", path: "users/#{URI.encode_uri_component(params[:id].to_s)}/authentication-methods", body: body_params, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Auth0::Internal::Types::Utils.coerce(Internal::Types::Array[Auth0::Types::SetUserAuthenticationMethodResponseContent], (response.body.to_s.empty? ? nil : JSON.parse(response.body, symbolize_names: true))) else error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#update(request_options: {}, **params) ⇒ Auth0::Types::UpdateUserAuthenticationMethodResponseContent
Modify the authentication method with the given ID from the specified user. For more information, review Manage Authentication Methods with Management API.
308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 |
# File 'lib/auth0/users/authentication_methods/client.rb', line 308 def update(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) request_data = Auth0::Users::AuthenticationMethods::Types::UpdateUserAuthenticationMethodRequestContent.new(params).to_h non_body_param_names = %w[id authentication_method_id] body = request_data.except(*non_body_param_names) request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "PATCH", path: "users/#{URI.encode_uri_component(params[:id].to_s)}/authentication-methods/#{URI.encode_uri_component(params[:authentication_method_id].to_s)}", body: body, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) (response.body.to_s.empty? ? nil : Auth0::Types::UpdateUserAuthenticationMethodResponseContent.load(response.body)) else error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |