Class: Auth0::Users::Authenticators::Client
- Inherits:
-
Object
- Object
- Auth0::Users::Authenticators::Client
- Defined in:
- lib/auth0/users/authenticators/client.rb
Instance Method Summary collapse
-
#delete_all(request_options: {}, **params) ⇒ untyped
Remove all authenticators registered to a given user ID, such as OTP, email, phone, and push-notification.
- #initialize(client:) ⇒ void constructor
Constructor Details
#initialize(client:) ⇒ void
10 11 12 |
# File 'lib/auth0/users/authenticators/client.rb', line 10 def initialize(client:) @client = client end |
Instance Method Details
#delete_all(request_options: {}, **params) ⇒ untyped
Remove all authenticators registered to a given user ID, such as OTP, email, phone, and push-notification. This action cannot be undone. For more information, review <a href=“auth0.com/docs/secure/multi-factor-authentication/manage-mfa-auth0-apis/manage-authentication-methods-with-management-api”>Manage Authentication Methods with Management API</a>.
29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 |
# File 'lib/auth0/users/authenticators/client.rb', line 29 def delete_all(request_options: {}, **params) params = Auth0::Internal::Types::Utils.normalize_keys(params) request = Auth0::Internal::JSON::Request.new( base_url: [:base_url], method: "DELETE", path: "users/#{URI.encode_uri_component(params[:id].to_s)}/authenticators", request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Auth0::Errors::TimeoutError end code = response.code.to_i return if code.between?(200, 299) error_class = Auth0::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end |